#
# spec file for package kitty
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# sphinx_copybutton not in Factory
%bcond_with docs
Name:           kitty
Version:        0.33.1
Release:        1.2
Summary:        A GPU-based terminal emulator
License:        GPL-3.0-only
Group:          System/X11/Terminals
URL:            https://github.com/kovidgoyal/kitty
Source:         https://github.com/kovidgoyal/kitty/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        vendor.tar.gz
Source2:        kitty-rpmlintrc
Patch0:         buildmode-and-skip_docs.diff
BuildRequires:  ImageMagick-devel
BuildRequires:  Mesa-libGL-devel
BuildRequires:  fdupes
BuildRequires:  fontconfig-devel
BuildRequires:  freetype2-devel
BuildRequires:  go >= 1.22
BuildRequires:  harfbuzz-devel >= 1.5.0
BuildRequires:  libXcursor-devel
BuildRequires:  libXi-devel
BuildRequires:  libXinerama-devel
BuildRequires:  libXrandr-devel
BuildRequires:  libcanberra-devel
BuildRequires:  liblcms2-devel
BuildRequires:  libpng16-compat-devel
BuildRequires:  librsync-devel
BuildRequires:  libxkbcommon-devel
BuildRequires:  libxkbcommon-x11-devel
BuildRequires:  ncurses-devel
BuildRequires:  openssl-devel
BuildRequires:  pkgconfig
BuildRequires:  terminfo
BuildRequires:  wayland-devel
BuildRequires:  wayland-protocols-devel
BuildRequires:  xxhash-devel
BuildRequires:  zlib-devel
BuildRequires:  pkgconfig(dbus-1)
BuildRequires:  pkgconfig(simde)
# Python requirements for Factory and Leap
%if 0%{?suse_version} > 1500
BuildRequires:  python3-devel >= 3.7
BuildRequires:  python3-sphinxext-opengraph
%else
# Leap still provides python3.6 kitty requires at least 3.7
%if 0%{?sle_version} > 150400
BuildRequires:  python311-devel
%else
%if 0%{?sle_version} > 150300
BuildRequires:  python310-devel
%else
BuildRequires:  python39-devel
%endif
%endif
%endif
# Optional documentation requirements
%if %{with docs}
BuildRequires:  python3-Sphinx >= 1.7
BuildRequires:  python3-importlib-resources
BuildRequires:  python3-readthedocs-sphinx-ext
BuildRequires:  python3-sphinx-inline-tabs
BuildRequires:  python3-sphinxcontrib-copybutton
%endif
Recommends:     %{name}-shell-integration
Recommends:     %{name}-terminfo
Recommends:     python3-importlib_resources

%description
A terminal emulator that uses OpenGL for rendering.
Supports terminal features like: graphics, Unicode,
true-color, OpenType ligatures, mouse protocol, focus tracking,
bracketed paste and so on, and which can be controlled by scripts.

%package terminfo
Summary:        The terminfo file for the Kitty terminal
BuildArch:      noarch

%description terminfo
Provides 'xterm-kitty' terminfo file(s) for the Kitty terminal; this package can be installed on its own to provide file(s) instead of the full kitty package on remote systems.

%package shell-integration
Summary:        The shell-integation file(s) for the Kitty terminal

%description shell-integration
shell-integration [bash,fish,zsh] file(s) for the Kitty terminal; this package can be installed on its own to provide file(s) instead of the full kitty package on remote systems.

%prep
%autosetup -p0 -a 1

%if 0%{?suse_version} > 1500
find . -type f -exec sed -i 's@#!/usr/bin/env python3$@#!%{_bindir}/python3@' {} +
find . -type f -exec sed -i 's@#!/usr/bin/env python$@#!%{_bindir}/python@' {} +
%else
%if 0%{?sle_version} > 150400
find . -type f -exec sed -i 's@#!/usr/bin/env python3$@#!%{_bindir}/python3.11@' {} +
find . -type f -exec sed -i 's@#!/usr/bin/env python$@#!%{_bindir}/python3.11@' {} +
%else
%if 0%{?sle_version} > 150300
find . -type f -exec sed -i 's@#!/usr/bin/env python3$@#!%{_bindir}/python3.10@' {} +
find . -type f -exec sed -i 's@#!/usr/bin/env python$@#!%{_bindir}/python3.10@' {} +
%else
find . -type f -exec sed -i 's@#!/usr/bin/env python3$@#!%{_bindir}/python3.9@' {} +
find . -type f -exec sed -i 's@#!/usr/bin/env python$@#!%{_bindir}/python3.9@' {} +
%endif
%endif
%endif

%build

%install
# yes they have a makefile, no they dont use it properly
# no they dont have a make install
# we used to have this in the build section but since rpm 4.16 buildroot is cleaned
#
# See: https://build.opensuse.org/request/show/1096854
# Set -Wno-error=switch flag to prevent compiler crashes
#export CFLAGS="${CFLAGS:-%%optflags} -Wno-error=switch"
#export CXXFLAGS="${CXXFLAGS:-%%optflags} -Wno-error=switch"
#
### This might have been fixed as part of #gh/kovidgoyal/kitty/7026
#%%ifarch i586
#export CFLAGS="${CFLAGS:-%%optflags} -fcf-protection=none"
#%%endif
#####
%if 0%{?suse_version} > 1500
python3 \
%else
%if 0%{?sle_version} > 150400
python3.11 -B \
%else
%if 0%{?sle_version} > 150300
python3.10 -B \
%else
python3.9 -B \
%endif
%endif
%endif
setup.py --verbose linux-package --prefix %{buildroot}%{_prefix} --libdir-name %{_lib}

%fdupes %{buildroot}%{_libdir}/%{name}

%files
%license LICENSE
%doc CHANGELOG.rst README.asciidoc
%{_bindir}/%{name}
%{_bindir}/kitten
%{_libdir}/%{name}
%exclude %{_libdir}/%{name}/shell-integration
%{_datadir}/applications/%{name}{,-open}.desktop
%{_datadir}/icons/hicolor/
%if %{with docs}
%{_mandir}/man1/%{name}.1%{?ext_man}
%{_datadir}/doc/%{name}
%{_mandir}/man5/kitty.conf.5%{?ext_man}
%endif

%files terminfo
%license LICENSE
%doc CHANGELOG.rst README.asciidoc
%{_datadir}/terminfo/x/xterm-%{name}

%files shell-integration
%license LICENSE
%doc CHANGELOG.rst README.asciidoc
%{_libdir}/%{name}/shell-integration

%changelog
* Thu Mar 21 2024 Scott Bradnick <scott.bradnick@suse.com>
- Update to 0.33.1:
  * Fix a regression in the previous release that caused requesting data from
    the clipboard via OSC 52 to instead return data from the primary
    selection (#7213)
  * Splits layout: Allow resizing until one of the halves in a split is
    minimally sized (#7220)
  * macOS: Fix text rendered with fallback fonts not respecting bold/italic
    styling (#7241)
  * macOS: When CoreText fails to find a fallback font for a character in the
    first Private Use Unicode Area, preferentially use the NERD font, if
    available, for it (#6043)
* Fri Mar 15 2024 Scott Bradnick <scott.bradnick@suse.com>
- 'pkgconfig(simde)' is now available in TW; adding updated go vendor tarball
- Setting 'BuildRequires: go >= 1.22'
* Tue Mar 12 2024 Scott Bradnick <scott.bradnick@suse.com>
- Adding 'BuildRequires: pkgconfig(simde)'
- Update to 0.33.0:
  * Cheetah speed with a redesigned render loop and a 2x faster escape code
    parser that uses SIMD CPU vector instruction to parse data in
    parallel (#7005)
  * A new benchmark kitten (kitten __benchmark__) to measure terminal
    throughput performance
  * Graphics protocol: Add a new delete mode for deleting images whose ids
    fall within a range. Useful for bulk deletion (#7080)
  * Keyboard protocol: Fix the Enter, Tab and Backspace keys generating
    spurious release events even when report all keys as escape codes is
    not set (#7136)
  * macOS: The command line args from macos-launch-services-cmdline are now
    prefixed to any args from open --args rather than overwriting them (#7135)
  * Allow specifying where the new tab is created for detach_window (#7134)
  * hints kitten: The option to set the text color for hints now allows
    arbitrary colors (#7150)
  * icat kitten: Add a command line argument to override terminal window size
    detection (#7165)
  * A new action toggle_tab to easily switch to and back from a tab with a
    single shortcut (#7203)
  * When clearing terminal add a new type to_cursor_scroll which can be used
    to clear to prompt while moving cleared lines into the scrollback
  * Fix a performance bottleneck when dealing with thousands of small
    images (#7080)
  * kitten @ ls: Return the timestamp at which the window was created (#7178)
  * hints kitten: Use default editor rather than hardcoding vim to open file
    at specific line (#7186)
  * Remote control: Fix --match argument not working for @ls, @send-key,
    @set-background-image (#7192)
  * Keyboard protocol: Do not deliver a fake key release events on OS window
    focus out for engaged modifiers (#7196)
  * Ignore startup_session when kitty is invoked with command line options
    specifying a command to run (#7198)
  * Box drawing: Specialize rendering for the Fira Code progress
    bar/spinner glyphs
* Mon Feb 26 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  PatchN.
* Mon Feb 12 2024 Scott Bradnick <scott.bradnick@suse.com>
- Update to 0.32.2:
  * kitten @ load-config: Allow (re)loading kitty.conf via remote control
  * Remote control: Allow running mappable actions via remote control
    (kitten @ action)
  * kitten @ send-text: Add a new option to automatically wrap the sent text
    in bracketed paste escape codes if the program in the destination window
    has turned on bracketed paste.
  * Fix a single key mapping not overriding a previously defined multi-key mapping
  * macOS: Fix kitten @ select-window leaving the keyboard in a partially
    functional state (#7074)
  * Graphics protocol: Improve display of images using Unicode placeholders or
    row/column boxes by resizing them using linear instead of nearest neighbor
    interpolation on the GPU (#7070)
  * When matching URLs use the definition of legal characters in URLs from the
    WHATWG spec rather than older standards (#7095)
  * hints kitten: Respect the kitty url_excluded_characters option (#7075)
  * macOS: Fix an abort when changing OS window chrome for a full screen window
    via remote control or the themes kitten (#7106)
  * Special case rendering of some more box drawing characters using shades from
    the block of symbols for legacy computing (#7110)
  * A new close_other_os_windows to close non active OS windows (#7113)
* Fri Jan 26 2024 Scott Bradnick <scott.bradnick@suse.com>
- #gh/kovidgoyal/kitty/7026 may have fixed -fcf-protection issue for i586
- Update to 0.32.1:
  * macOS: Fix a regression in the previous release that broke overriding
    keyboard shortcuts for actions present in the global menu bar (#7016)
  * Fix a regression in the previous release that caused multi-key
    sequences to not abort when pressing an unknown key (#7022)
  * Fix a regression in the previous release that caused
    kitten @ launch --cwd=current to fail over SSH (#7028)
  * Fix a regression in the previous release that caused
    kitten @ send-text with a match tab parameter to send text twice to
    the active window (#7027)
  * Fix a regression in the previous release that caused overriding of
    existing multi-key mappings to fail (#7044, #7058)
  * Wayland+NVIDIA: Do not request an sRGB output buffer as a bug in Wayland
    causes kitty to not start (#7021)
* Fri Jan 19 2024 Scott Bradnick <scott.bradnick@suse.com>
- i586 builds fail with -fcf-protection=full (seems to be default);
  setting to -fcf-protection=none with CFLAGS export
* Fri Jan 19 2024 Scott Bradnick <scott.bradnick@suse.com>
- Removing go-buildmode-pie.diff and optional-disable-docs.diff; replacing
  with buildmode-and-skip_docs.diff which should be an easier path going
  forward to disabling 'make docs' from setup.py
- Update to 0.32.0:
  * Conditional mappings depending on the state of the focused window
  * Support for Modal mappings such as in modal editors like vim
  * A new option notify_on_cmd_finish to show a desktop notification
    when a long running command finishes (#6817)
  * A new action send_key to simplify mapping key presses to other
    keys without needing send_text
  * Allow focusing previously active OS windows via nth_os_window (#7009)
  * Wayland: Fix a regression in the previous release that broke copying
    to clipboard under wl-roots based compositors in some circumstances (#6890)
  * macOS: Fix some combining characters not being rendered (#6898)
  * macOS: Fix returning from full screen via the button when the titlebar
    is hidden not hiding the buttons (#6883)
  * macOS: Fix newly created OS windows not always appearing on the
    "active" monitor (#6932)
  * Font fallback: Fix the font used to render a character sometimes dependent
    on the order in which characters appear on screen (#6865)
  * panel kitten: Fix rendering with non-zero margin/padding in
    kitty.conf (#6923)
  * kitty keyboard protocol: Specify the behavior of the modifier bits during
    modifier key events (#6913)
  * Wayland: Enable support for the new cursor-shape protocol so that the
    mouse cursor is always rendered at the correct size in compositors that
    support this protocol (#6914)
  * GNOME Wayland: Fix remembered window size smaller than actual size (#6946)
  * Mouse reporting: Fix incorrect position reported for windows with
    padding (#6950)
  * Fix focus_visible_window not switching to other window in stack layout
    when only two windows are present (#6970)
* Wed Nov  8 2023 Scott Bradnick <scott.bradnick@suse.com>
- Update to 0.31.0:
  * Allow easily running arbitrarily complex remote control scripts without
    needing to turn on remote control (#6712)
  * A new option menu_map that allows adding entries to the global menubar on
    macOS (#6680)
  * A new escape code that can be used by programs running in the terminal to
    change the shape of the mouse pointer (#6711)
  * Graphics protocol: Support for positioning images relative to other
    images (#6400)
  * A new option single_window_padding_width to use a different padding when
    only a single window is visible (#6734)
  * A new mouse action mouse_selection word_and_line_from_point to select the
    current word under the mouse cursor and extend to end of line (#6663)
  * A new option underline_hyperlinks to control when hyperlinks are
    underlined (#6766)
  * Allow using the full range of standard mouse cursor shapes when customizing
    the mouse cursor
  * macOS: When running the default shell with the login program fix
    ~/.hushlogin not being respected when opening windows not in the home
    directory (#6689)
  * macOS: Fix poor performance when using ligatures with some fonts,
    caused by slow harfbuzz shaping (#6743)
  * kitten @ set-background-opacity --toggle - a new flag to easily switch
    opacity between the specified value and the default (#6691)
  * Fix a regression caused by rewrite of kittens to Go that made various
    kittens reset colors in a terminal when the colors were changed by
    escape code (#6708)
  * Fix trailing bracket not ignored when detecting a multi-line URL with the
    trailing bracket as the first character on the last line (#6710)
  * Fix the kitten @ launch --copy-env option not copying current environment
    variables (#6724)
  * Fix a regression that broke kitten update-self (#6729)
  * Two new event types for watchers, on_title_change and on_set_user_var
  * When pasting, if the text contains terminal control codes ask the user for
    permission. See paste_actions for details. Thanks to David Leadbeater for
    discovering this.
  * Render Private Use Unicode symbols using two cells if the second cell
    contains an en-space as well as a normal space
  * macOS: Fix a regression in the previous release that caused kitten @ ls to
    not report the environment variables for the default shell (#6749)
  * Desktop notification protocol: Allow applications sending notifications to
    specify that the notification should only be displayed if the window is
    currently unfocused (#6755)
  * unicode_input kitten: Fix a regression that broke the "Emoticons"
    tab (#6760)
  * Shell integration: Fix sudo --edit not working and also fix completions for
    sudo not working in zsh (#6754, #6771)
  * A new action set_window_title to interactively change the title of the
    active window
  * ssh kitten: Fix a regression that broken ctrl+space mapping in zsh (#6780)
  * Wayland: Fix primary selections not working with the river
    compositor (#6785)
* Thu Oct  5 2023 Scott Bradnick <scott.bradnick@suse.com>
- Update to 0.30.1:
  * Shell integration: Automatically alias sudo to make the kitty terminfo
    files available in the sudo environment. Can be turned off via shell_integration
  * ssh kitten: Fix a regression in 0.28.0 that caused using --kitten to
    override ssh.conf not inheriting settings from ssh.conf (#6639)
  * themes kitten: Allow absolute paths for --config-file-name (#6638)
  * Expand environment variables in the shell option (#6511)
  * macOS: When running the default shell, run it via the login program so that
    calls to getlogin() work (#6511)
  * X11: Fix a crash on startup when the ibus service returns errors and the
    GLFW_IM_MODULE env var is set to ibus (#6650)
* Thu Sep 21 2023 Scott Bradnick <scott.bradnick@suse.com>
- Removing fix-librsync-leap.diff (no longer needed)
- Updating optional-disable-docs.diff for changes to setup.py
- Updating go vendor tarball
- Update to 0.30.0:
  * A new transfer kitten that can be used to transfer files efficiently over
    the TTY device
  * ssh kitten: A new configuration directive to automatically forward the
    kitty remote control socket
  * Allow easily building kitty from source needing the installation of only
    C and Go compilers. All other dependencies are automatically vendored
  * kitten @ set-user-vars: New remote control command to set user variables
    on a window (#6502)
  * kitten @ ls: Add user variables set on windows to the output (#6502)
  * kitten @ ls: Allow limiting output to matched windows/tabs (#6520)
  * kitten icat: Fix image being displayed one cell to the right when using
    both --place and --unicode-placeholder (#6556)
  * kitten run-shell: Make kitty terminfo database available if needed before
    starting the shell
  * macOS: Fix keyboard shortcuts in the Apple global menubar not being
    changed when reloading the config
  * Fix a crash when resizing an OS Window that is displaying more than one
    image and the new size is smaller than the image needs (#6555)
  * Remote control: Allow using a random TCP port as the remote control
    socket and also allow using TCP sockets in listen_on
  * unicode_input kitten: Add an option to specify the startup tab (#6552)
  * X11: Print an error to STDERR instead of refusing to start when the user
    sets a custom window icon larger than 128x128 (#6507)
  * Remote control: Allow matching by neighbor of active window. Useful for
    navigation plugins like vim-kitty-navigator
  * Fix a regression that caused changing text_fg_override_threshold or
    text_composition_strategy via config reload causing incorrect rendering (#6559)
  * When running a shell for --hold set the env variable KITTY_HOLD=1 to allow
    users to customize what happens (#6587)
  * When multiple confirmable close requests are made focus the existing close
    confirmation window instead of opening a new one for each request (#6601)
  * Config file format: allow splitting lines by starting subsequent lines
    with a backslash (#6603)
  * ssh kitten: Fix a regression causing hostname directives in ssh.conf not
    matching when username is specified (#6609)
  * diff kitten: Add support for files that are identical apart from mode
    changes (#6611)
  * Wayland: Do not request idle inhibition for full screen windows (#6613)
  * Adjust the workaround for non-linear blending of transparent pixels in
    compositors to hopefully further reduce fringing around text with certain
    color issues (#6534)
* Thu Jul 27 2023 Michael Vetter <mvetter@suse.com>
- Update to 0.29.2:
  * Detect .tex and Makefiles as plain text files (#6492)
  * unicode_input kitten: Fix scrolling over multiple screens not working (#6497)
* Mon Jul 17 2023 Scott Bradnick <scott.bradnick@suse.com>
- Update to 0.29.1
  * A new value for background_image_layout to scale the background image while
    preserving its aspect ratio. Also have centered images work even for images
    larger than the window size (#6458)
  * Fix a regression that caused using unicode placeholders to display images to
    break and also partially offscreen images to sometimes be slightly
    distorted (#6467)
  * macOS: Fix a regression that caused rendering to hang when transitioning to
    full screen with macos_colorspace set to default (#6435)
  * macOS: Fix a regression causing burn-in of text when resizing semi-transparent
    OS windows (#6439)
  * macOS: Add a new value titlebar-and-corners for hide_window_decorations that
    emulates the behavior of hide_window_decorations yes in older versions of kitty
  * macOS: Fix a regression in the previous release that caused
    hide_window_decorations = yes to prevent window from being resizable (#6436)
  * macOS: Fix a regression that caused the titlebar to be translucent even for
    non-translucent windows (#6450)
  * GNOME: Fix wayland_titlebar_color not being applied until the color is changed
    at least once (#6447)
  * Remote control launch: Fix --env not implemented when using --cwd=current with
    the SSH kitten (#6438)
  * Allow using a custom OS window icon on X11 as well as macOS (#6475)
* Mon Jul 10 2023 Scott Bradnick <scott.bradnick@suse.com>
- Adding kitty-rpmlintrc as a source file
* Mon Jul 10 2023 Scott Bradnick <scott.bradnick@suse.com>
- Update to 0.29.0
  * Removing wayland-protocols-1.32.diff as it's no longer required
  * A new escape code <ESC>[22J that moves the current contents of the screen
    into the scrollback before clearing it
  * A new kitten run-shell to allow creating sub-shells with shell integration
    enabled
  * A new option background_blur to blur the background for transparent
    windows (#6135)
  * The --hold flag now holds the window open at a shell prompt instead of
    asking the user to press a key
  * A new option text_fg_override_threshold to force text colors to have high
    contrast regardless of color scheme (#6283)
  * When resizing OS Windows make the animation less jerky. Also show the
    window size in cells during the resize (#6341)
  * unicode_input kitten: Fix a regression in 0.28.0 that caused the order of
    recent and favorites entries to not be respected (#6214)
  * unicode_input kitten: Fix a regression in 0.28.0 that caused editing of
    favorites to sometimes hang
  * clipboard kitten: Fix a bug causing the last MIME type available on the
    clipboard not being recognized when pasting
  * clipboard kitten: Dont set clipboard when getting clipboard in filter
    mode (#6302)
  * Fix regression in 0.28.0 causing color fringing when rendering in
    transparent windows on light backgrounds (#6209)
  * show_key kitten: In kitty mode show the actual bytes sent by the terminal
    rather than a re-encoding of the parsed key event
  * hints kitten: Fix a regression in 0.28.0 that broke using sub-groups in
    regexp captures (#6228)
  * hints kitten: Fix a regression in 0.28.0 that broke using
    lookahead/lookbehind in regexp captures (#6265)
  * diff kitten: Fix a regression in 0.28.0 that broke using relative paths
    as arguments to the kitten (#6325)
  * Fix re-using the image id of an animated image for a still image causing
    a crash (#6244)
  * kitty +open: Ask for permission before executing script files that are not
    marked as executable. This prevents accidental execution of script files
    via MIME type association from programs that unconditionally “open”
    attachments/downloaded files
  * edit-in-kitty: Fix running edit-in-kitty with elevated privileges to edit a
    restricted file not working (#6245)
  * ssh kitten: Fix a regression in 0.28.0 that caused interrupt during setup
    to not be handled gracefully (#6254)
  * ssh kitten: Allow configuring the ssh kitten to skip some hosts via a new
    delegate config directive
  * Graphics: Move images up along with text when the window is shrunk
    vertically (#6278)
  * Fix a regression in 0.28.0 that caused a buffer overflow when clearing the
    screen (#6306, #6308)
  * Fix a regression in 0.27.0 that broke setting of specific edge
    padding/margin via remote control (#6333)
  * macOS: Fix window shadows not being drawn for transparent
    windows (#2827, #6416)
  * Do not echo invalid DECRQSS queries back, behavior inherited from xterm
    (CVE-2008-2383). Similarly, fix an echo bug in the file transfer protocol
    due to insufficient sanitization of safe strings.
* Fri Jul  7 2023 Scott Bradnick <scott.bradnick@suse.com>
- patch file fix-librsync-leap.patch is being deleted as part of a rename
- patch file fix-librsync-leap.diff is being added as part of a rename
- patch optional-disable-docs.patch is being deleted as part of a rename
- patch optional-disable-docs.diff is being added as part of a rename
- patch go-buildmode-pie.diff is being added so that 'go build' includes '-buildmode=pie'
* Thu Jul  6 2023 Scott Bradnick <scott.bradnick@suse.com>
- Adding wayland-protocols-1.32.diff patch to account for 'compiler crashes'
  from wayland-protocols-devel update (#6422)
  * This is patched upstream via 95d1564 and 7d2dc25
- Removing -Wno-error=switch flag as this was a workaround to deal with
  scenario from above
* Tue Jul  4 2023 Scott Bradnick <scott.bradnick@suse.com>
- Renaming the following files:
  * fix-librsync-leap{.patch -> .diff}
  * optional-disable-docs{.patch -> diff}
* Tue Jul  4 2023 Simon Vogl <simon.vogl@gmx.net>
- Set -Wno-error=switch flag to prevent compiler crashes for RISCV
  and ARM
* Thu Jun 29 2023 Scott Bradnick <scott.bradnick@suse.com>
- Cleaning up "wayland-devel obsoletes libwayland-egl-devel"
- Adding 'Recommends: python3-importlib_resources'
* Tue May  9 2023 Max Lin <mlin@suse.com>
- Use python3.11 on Leap 15.5
  * python3.11 is the only python3 > 3.6 version would be shipped
    in Leap 15.5
* Fri Apr 21 2023 Simon Vogl <simon.vogl@gmx.net>
- Update to 0.28.1:
  * Fix a regression in the previous release that broke the remote file kitten (#6186)
  * Fix a regression in the previous release that broke handling of some keyboard shortcuts in some kittens on some keyboard layouts (#6189)
  * Fix a regression in the previous release that broke usage of custom themes (#6191)
* Sat Apr 15 2023 Simon Vogl <simon.vogl@gmx.net>
- Update to 0.28.0:
  * Text rendering change: Use sRGB correct linear gamma blending
    for nicer font rendering and better color accuracy with
    transparent windows. See the option text_composition_strategy for details.
    The obsolete macos_thicken_font will make the font too thick
    and needs to be removed manually if it is configured. (#5969)
  * icat kitten: Support display of images inside tmux >= 3.3 (#5664)
  * Graphics protocol: Add support for displaying images inside programs
    that do not support the protocol such as vim and tmux (#5664)
  * diff kitten: Add support for selecting multi-line text with the mouse
  * Fix a regression in 0.27.0 that broke kitty @ set-font-size 0 (#5992)
  * launch: When using --cwd=current for a remote system support
    running non shell commands as well (#5987)
  * When changing the cursor color via escape codes or remote control
    to a fixed color, do not reset cursor_text_color (#5994)
  * Input Method Extensions: Fix incorrect rendering of IME in-progress
    and committed text in some situations (#6049, #6087)
  * Linux: Reduce minimum required OpenGL version from 3.3
    to 3.1 + extensions (#2790)
  * Fix a regression that broke drawing of images below cell backgrounds (#6061)
  * When reloading configuration, also reload custom MIME types
    from mime.types config file (#6012)
  * launch: Allow specifying the state (full screen/maximized/minimized)
    for newly created OS Windows (#6026)
  * Sessions: Allow specifying the OS window state via
    the os_window_state directive (#5863)
  * Linux: A new option linux_bell_theme to control which sound theme
    is used for the bell sound (#4858)
  * ssh kitten: Change the syntax of glob patterns slightly to match common
    usage elsewhere. Now the syntax is the same as “extendedglob” in most shells.
  * hints kitten: Allow copying matches to named buffers (#6073)
  * Fix overlay windows not inheriting the per-window padding
    and margin settings of their parents (#6063)
  * Wayland KDE: Fix selecting in un-focused OS window not working correctly (#6095)
  * Linux X11: Fix a crash if the X server requests clipboard data
    after we have relinquished the clipboard (#5650)
  * Allow stopping of URL detection at newlines via url_excluded_characters (#6122)
  * Linux Wayland: Fix animated images not being animated continuously (#6126)
  * Keyboard input: Fix text not being reported as unicode codepoints
    for multi-byte characters in the kitty keyboard protocol (#6167)
* Mon Mar 13 2023 Simon Vogl <simon.vogl@gmx.net>
- Adjust optional-disable-docs.patch for new version
- Add _service and vendor.tar.gz to to download, verify, and vendor Go module dependency sources
- Drop support for openSUSE Leap 15.4 as it cannot provide go1.20
- Update to 0.27.0 & 0.27.1:
  * Fix modify_font not working for strikethrough position (#5946)
  * Fix a regression causing the edit-in-kitty command not working
    if kitten is not added to PATH (#5956)
  * icat kitten: Fix a regression that broke display of animated
    GIFs over SSH (#5958)
  * Wayland GNOME: Fix for ibus not working when using XWayland (#5967)
  * Fix regression in previous release that caused incorrect entries
    in terminfo for modifier+F3 key combinations (#5970)
  * Bring back the deprecated and removed kitty +complete and delegate
    it to kitten for backward compatibility (#5977)
  * Bump the version of Go needed to build kitty to 1.20 so we can
    use the Go stdlib ecdh package for crypto.
  * A new statically compiled, standalone executable, kitten (written in Go)
    that can be used on all UNIX-like servers for remote control (kitten @),
    viewing images (kitten icat), manipulating the
    clipboard (kitten clipboard), etc.
  * clipboard kitten: Allow copying arbitrary data types to/from
    the clipboard, not just plain text
  * Speed up the kitty @ executable by ~10x reducing the time for
    typical remote control commands from ~50ms to ~5ms
  * icat kitten: Speed up by using POSIX shared memory when possible
    to transfer image data to the terminal. Also support common image
    formats GIF/PNG/JPEG/WEBP/TIFF/BMP out of the box without needing ImageMagick.
  * Option show_hyperlink_targets to show the target of terminal
    hyperlinks when hovering over them with the mouse (#5830)
  * Keyboard protocol: Remove CSI R from the allowed encodings of
    the F3 key as it conflicts with the Cursor Position Report escape code (#5813)
  * Allow using the cwd of the original process for launch --cwd (#5672)
  * Session files: Expand environment variables (#5917)
  * Pass key events mapped to scroll actions to the program running in
    the terminal when the terminal is in alternate screen mode (#5839)
  * Implement edit-in-kitty using the new kitten static executable (#5546, #5630)
  * Add an option background_tint_gaps to control background image
    tinting for window gaps (#5596)
  * A new option undercurl_style to control the rendering of undercurls (#5883)
  * Bash integration: Fix clone-in-kitty not working on bash >= 5.2 if environment
    variable values contain newlines or other special characters (#5629)
  * A new sleep action useful in combine based mappings to make
    kitty sleep before executing the next action
  * Wayland GNOME: Workaround for latest mutter release breaking full
    screen for semi-transparent kitty windows (#5677)
  * A new option tab_title_max_length to limit the length of tab (#5718)
  * When drawing the tab bar have the default left and right margins
    drawn in a color matching the neighboring tab (#5719)
  * When using the include directive in kitty.conf make the environment
    variable KITTY_OS available for OS specific config
  * Wayland: Fix signal handling not working with some GPU drivers (#4636)
  * Remote control: When matching windows allow using negative id numbers
    to match recently created windows (#5753)
  * ZSH Integration: Bind alt+left and alt+right to move by word if not already bound.
    This mimics the default bindings in Terminal.app (#5793)
  * When a multi-key sequence does not match any action,
    send all key events to the child program (#5841)
  * broadcast kitten: Allow pressing a key to stop echoing of
    input into the broadcast window itself (#5868)
  * When reporting unused activity in a window, ignore activity
    that occurs soon after a window resize (#5881)
  * Fix using cursor = none not working on text that has reverse video (#5897)
* Mon Nov  7 2022 Michael Vetter <mvetter@suse.com>
- Update to 0.26.5:
  * Splits layout: Add a new mappable action to move the active
    window to the screen edge (#5643)
  * ssh kitten: Allow using absolute paths for the location of
    transferred data (#5607)
  * Fix a regression in the previous release that caused a
    resize_draw_strategy of static to not work (#5601)
  * Wayland KDE: Fix abort when pasting into Firefox (#5603)
  * Wayland GNOME: Fix ghosting when using background_tint (#5605)
  * Fix cursor position at x=0 changing to x=1 on resize (#5635)
  * Wayland GNOME: Fix incorrect window size in some circumstances
    when switching between windows with window decorations disabled (#4802)
  * Wayland: Fix high CPU usage when using some input methods (#5369)
  * Remote control: When matching window by state:focused and no window
    currently has keyboard focus, match the window belonging to the OS
    window that was last focused (#5602)
* Tue Oct 18 2022 Michael Vetter <mvetter@suse.com>
- Update to 0.26.4:
  * Allow centering the background_image (#5525)
  * X11: Fix a regression in the previous release that caused pasting
    from GTK based applications to have extra newlines (#5528)
  * Tab bar: Improve empty space management when some tabs have
    short titles, allocate the saved space to the active tab (#5548)
  * Fix background_tint not applying to window margins and padding (#3933)
  * Wayland: Fix background image scaling using tiled mode on
    high DPI screens
  * Wayland: Fix an abort when changing background colors with
    wayland_titlebar_color set to background (#5562)
  * Update to Unicode 15.0 (#5542)
  * GNOME Wayland: Fix a memory leak in gnome-shell when using client
    side decorations
* Mon Sep 26 2022 Michael Vetter <mvetter@suse.com>
- Update to 0.26.3:
  * Wayland: Mark windows in which a bell occurs as urgent on compositors
    that support the xdg-activation protocol
  * Allow passing null bytes through the system clipboard (#5483)
  * ssh kitten: Fix KITTY_PUBLIC_KEY not being encoded properly
    when transmitting (#5496)
  * Sessions: Allow controlling which OS Window is active via
    the focus_os_window directive
  * Wayland: Fix for bug in NVIDIA drivers that prevents
    transparency working (#5479)
  * Wayland: Fix for a bug that could cause kitty to become
    non-responsive when using multiple OS windows in a single
    instance on some compositors (#5495)
  * Wayland: Fix for a bug preventing kitty from starting on
    Hyprland when using a non-unit scale (#5467)
  * Wayland: Generate a XDG_ACTIVATION_TOKEN when opening URLs
    or running programs in the background via the launch action
  * Fix a regression that caused kitty not to restore SIGPIPE
    after python nukes it when launching children. Affects bash
    which does not sanitize its signal mask. (#5500)
  * Fix a use-after-free when handling fake mouse clicks and the
    action causes windows to be removed/re-allocated (#5506)
* Mon Sep  5 2022 Michael Vetter <mvetter@suse.com>
- Update to 0.26.2:
  * Allow creating overlay-main windows, which are treated as the
    active window unlike normal overlays (#5392)
  * hints kitten: Allow using The launch command as the program to run, to open the
    result in a new kitty tab/window/etc. (#5462)
  * hyperlinked_grep kitten: Allow control over which parts of rg output are
    hyperlinked (#5428)
  * Fix regression in 0.26.0 that caused launching kitty without working STDIO
    handles to result in high CPU usage and prewarming failing (#5444)
  * The launch command: Allow setting the margin and padding for newly created
    windows (#5463)
  * hints kitten: hyperlink matching: Fix hints occasionally matching text on
    subsequent line as part of hyperlink (#5450)
  * Fix a regression in 0.26.0 that broke mapping of native keys whose key codes
    did not fit in 21 bits (#5452)
  * Wayland: Fix remembering window size not accurate when client side decorations
    are present
  * Fix an issue where notification identifiers were not sanitized leading to code
    execution if the user clicked on a notification popup from a malicious source.
* Thu Sep  1 2022 Michael Vetter <mvetter@suse.com>
- Update to 0.26.1:
  * ssh kitten: Fix executable permission missing from kitty bootstrap script (#5438)
  * Allow specifying a title when using the set_tab_title action (#5441)
* Mon Aug 29 2022 Michael Vetter <mvetter@suse.com>
- Update to 0.26.0:
  * A new option remote_control_password to use fine grained permissions
    for what can be remote controlled (#5320)
  * Reduce startup latency by ~30 milliseconds when running kittens
    via key bindings inside kitty (#5159)
  * A new option modify_font to adjust various font metrics like
    underlines, cell sizes etc. (#5265)
  * A new shortcut ctrl+shift+f1 to display the kitty docs in a browser
  * Graphics protocol: Only delete temp files if they have the
    string tty-graphics-protocol in their file paths. This prevents
    deletion of arbitrary files in /tmp.
  * Deprecate the adjust_baseline, adjust_line_height and
    adjust_column_width options in favor of modify_font
  * Wayland: Fix a regression in the previous release that caused
    mouse cursor animation and keyboard repeat to stop working when switching seats (#5188)
  * Allow resizing windows created in session files (#5196)
  * Fix horizontal wheel events not being reported to client programs
    when they grab the mouse (#2819)
  * kitty @ set-colors: Fix changing inactive_tab_foreground not working (#5214)
  * Add a mappable action to toggle the mirrored setting for the tall and fat layouts (#5344)
  * Add a mappable action to switch between predefined bias values
    for the tall and fat layouts (#5352)
  * Wayland: Reduce flicker at startup by not using render frames
    immediately after a resize (#5235)
  * Linux: Update cursor position after all key presses not just
    pre-edit text changes (#5241)
  * ssh kitten: Allow ssh kitten to work from inside tmux, provided
    the tmux session inherits the correct KITTY env vars (#5227)
  * ssh kitten: A new option --symlink-strategy to control how
    symlinks are copied to the remote machine (#5249)
  * ssh kitten: Allow pressing Ctrl+C to abort ssh before the connection
    is completed (#5271)
  * Bash integration: Fix declare not creating global variables in .bashrc (#5254)
  * Bash integration: Fix the inherit_errexit option being set by shell integration (#5349)
  * kitty @ scroll-window allow scrolling by fractions of a screen (#5294)
  * remote files kitten: Fix working with files whose names have characters that
    need to be quoted in shell scripts (#5313)
  * Expand ~ in paths configured in editor and exe_search_path (#5298)
  * Allow showing the working directory of the active window in tab titles (#5314)
  * ssh kitten: Allow completion of ssh options between the destination and command (#5322)
  * Allow ignoring failure to close windows/tabs via rc commands (#5406)
  * Fix hyperlinks not present when fetching text from the history buffer (#5427)
* Tue Jun  7 2022 Michael Vetter <mvetter@suse.com>
- Update to 0.25.2:
  * A new command edit-in-kitty to Edit files in new kitty windows
    even over SSH
  * Allow getting the last non-empty command output easily via an
    action or remote control (#4973)
  * Fix a bug that caused macos_colorspace to always be default
    regardless of its actual value (#5129)
  * diff kitten: A new option kitten-diff.ignore_name to exclude
    files and directories from being scanned (#5171)
  * ssh kitten: Fix bash not being executed as a login shell since
    kitty 0.25.0 (#5130)
  * Themes kitten: Add a tab to show user defined custom color themes
    separately (#5150)
  * Iosevka: Fix incorrect rendering when there is a combining char
    that does not group with its neighbors (#5153)
  * Weston: Fix client side decorations flickering on slow computers
    during window resize (#5162)
  * Remote control: Fix commands with large or asynchronous payloads
    like kitty @ set-backround-image, kitty @ set-window-logo and
    kitty @ select-window not working correctly when using a
    socket (#5165)
  * hints kitten: Fix surrounding quotes/brackets and embedded
    carriage returns not being removed when using line number
    processing (#5170)
* Fri May 27 2022 Michael Vetter <mvetter@suse.com>
- Update to 0.25.1:
  * Shell integration: Add a command to Clone the current shell into
    a new window
  * Remote control: Allow using Boolean operators when constructing
    queries to match windows or tabs
  * Sessions: Fix os_window_size and os_window_class not applying
    to the first OS Window (#4957)
  * Allow using the cwd of the oldest as well as the newest foreground
    process for launch --cwd (#4869)
  * Bash integration: Fix the value of shell_integration not taking
    effect if the integration script is sourced in bashrc (#4964)
  * Fix a regression in the previous release that caused mouse move
    events to be incorrectly reported as drag events even when a button
    is not pressed (#4992)
  * remote file kitten: Integrate with the ssh kitten for improved
    performance and robustness. Re-uses the control master connection
    of the ssh kitten to avoid round-trip latency.
  * Fix tab selection when closing a new tab not correct in some scenarios (#4987)
  * A new action open_url to open the specified URL (#5004)
  * A new option select_by_word_characters_forward that allows changing
    which characters are considered part of a word to the right when
    double clicking to select words (#5103)
  * Fix reloading of config not working when kitty.conf does not exist
    when kitty is launched (#5071)
  * Fix deleting images by row not calculating image bounds correctly (#5081)
  * Increase the max number of combining chars per cell from two to three,
    without increasing memory usage.
  * Linux: Load libfontconfig at runtime to allow the binaries to work for
    running kittens on servers without FontConfig
  * GNOME: Fix for high CPU usage caused by GNOME’s text input subsystem
    going into an infinite loop when IME cursor position is updated
    after a done event (#5105)
* Mon Apr 18 2022 Ferdinand Thiessen <rpm@fthiessen.de>
- Fixed SPEC to build with Leap
- Replaced kitty-no-docs.patch with optional-disable-docs.patch
  * Some Sphinx extensions needed by kitty are not available
    in Factory
- Added fix-librsync-leap.patch
  * Workaround for "error: unknown type name ‘FILE’" in old librsync
    header still used by Leap 15.3 and 15.4.
* Tue Apr 12 2022 Michael Vetter <mvetter@suse.com>
- Update to 0.25.0:
  * Truly convenient SSH: automatic shell integration when using SSH.
    Easily clone local shell and editor configuration on remote machines,
    and automatic re-use of existing connections to avoid connection setup latency.
  * When pasting URLs at shell prompts automatically quote them. Also allow
    filtering pasted text and confirm pastes. See paste_actions for details. (#4873)
  * diff kitten: Fix incorrect rendering in rare circumstances when scrolling
    after changing the context size (#4831)
  * icat kitten: Fix a regression that broke kitty +kitten icat --print-window-size (#4818)
  * Wayland: Fix hide_window_decorations causing docked windows to be resized on blur (#4797)
  * Bash integration: Prevent shell integration code from running twice if user
    enables both automatic and manual integration
  * Bash integration: Handle existing PROMPT_COMMAND ending with a literal newline
  * Fix continued lines not having their continued status reset on line feed (#4837)
  * Wayland: Fix a regression that broke IME when changing windows/tabs (#4853)
  * Avoid flicker when starting kittens such as the hints kitten (#4674)
  * A new action scroll_prompt_to_top to move the current prompt to the top (#4891)
  * select_tab: Use stable numbers when selecting the tab (#4792)
  * Only check for updates in the official binary builds. Distro packages or source
    builds will no longer check for updates, regardless of the value of update_check_interval.
  * Fix inactive_text_alpha still being applied to the cursor hidden window after focus (#4928)
  * Fix resizing window that is extra tall/wide because of left-over cells not working reliably (#4913)
  * A new action close_other_tabs_in_os_window to close other tabs in the active OS window (#4944)
* Mon Mar  7 2022 Michael Vetter <mvetter@suse.com>
- Update to 0.24.4:
  * Shell integration: Fix the default Bash $HISTFILE changing
    to ~/.sh_history instead of ~/.bash_history (#4765)
  * Linux binaries: Fix binaries not working on systems with older
    Wayland client libraries (#4760)
  * Fix a regression in the previous release that broke kittens
    launched with STDIN not connected to a terminal (#4763)
  * Wayland: Fix surface configure events not being acknowledged
    before commit the resized buffer (#4768)
* Mon Feb 28 2022 Michael Vetter <mvetter@suse.com>
- Update to 0.24.3:
  * Bash integration: No longer modify ~/.bashrc to load shell
    integration. It is recommended to remove the lines used to load
    the shell integration from ~/.bashrc as they are no-ops.
  * Splits layout: A new value for launch --location to auto-select
    the split axis when splitting existing windows. Wide windows
    are split side-by-side and tall windows are split one-above-the-other
  * hints kitten: Fix a regression that broke recognition of
    path:linenumber:colnumber (#4675)
  * Fix a regression in the previous release that broke
    active_tab_foreground (#4620)
  * Fix show_last_command_output not working when the output is
    stored partially in the scrollback pager history buffer (#4435)
  * When dropping URLs/files onto kitty at a shell prompt insert
    them appropriately quoted and space separated (#4734)
  * Improve CWD detection when there are multiple foreground processes
    in the TTY process group
  * A new option narrow_symbols to turn off opportunistic wide rendering
    of private use codepoints
  * ssh kitten: Fix location of generated terminfo files on NetBSD (#4622)
  * A new action to clear the screen up to the line containing the
    cursor, see clear_terminal
  * A new action copy_ansi_to_clipboard to copy the current selection
    with ANSI formatting codes (#4665)
  * Linux: Do not rescale fallback fonts to match the main font cell
    height, instead just set the font size and let FreeType take care
    of it. This matches rendering on macOS (#4707)
  * Fix a regression in the previous release that broke strikethrough (#4632)
  * A new action scroll_prompt_to_bottom to move the current prompt to
    the bottom, filling in the window from the scrollback (#4634)
  * Add two special arguments @first-line-on-screen and @last-line-on-screen
    for the launch command to be used for pager positioning. (#4462)
  * Linux: Fix rendering of emoji when using scalable fonts such as Segoe UI Emoji
  * Shell integration: bash: Dont fail if an existing PROMPT_COMMAND
    ends with a semi-colon (#4645)
  * Shell integration: bash: Fix rendering of multiline prompts with
    more than two lines (#4681)
  * Shell integration: fish: Check fish version 3.3.0+ and exit on
    outdated versions (#4745)
  * Shell integration: fish: Fix pipestatus being overwritten (#4756)
  * Linux: Fix fontconfig alias not being used if the aliased font is
    dual spaced instead of monospaced (#4649)
  * Fix touch_scroll_multiplier also taking effect in terminal programs
    such as vim that handle mouse events themselves (#4680)
  * Fix symbol/PUA glyphs loaded via symbol_map instead of as fallbacks
    not using following spaces to render larger versions (#4670)
  * Fix a fast click, move mouse, click sequence causing the first click
    event to be discarded (#4603)
  * Wayland: Fix wheel mice with line based scrolling being incorrectly
    handled as high precision devices (#4694)
  * Wayland: Fix touchpads and high resolution wheels not scrolling at the
    same speed on monitors with different scales (#4703)
  * Add an option wheel_scroll_min_lines to set the minimum number of lines
    for mouse wheel scrolling when using a mouse with a wheel that generates
    very small offsets when slow scrolling (#4710)
  * Fix copying of selection after selection has been scrolled off history
    bufferraising an error (#4713)
* Thu Feb  3 2022 Michael Vetter <mvetter@suse.com>
- Update to 0.24.2:
  * Allow including config files matching glob patterns in
    kitty.conf (#4533)
  * Shell integration: Fix bash integration not working when
    PROMPT_COMMAND is used to change the prompt variables (#4476)
  * Shell integration: Fix cursor shape not being restored to
    default when running commands in the shell
  * Improve the UI of the ask kitten (#4545)
  * Allow customizing the placement and formatting of the
    tab_activity_symbol and bell_on_tab symbols by adding
    them to the tab_title_template (#4581, #4507)
  * hints kitten: Fix common single letter extension files
    not being detected (#4491)
  * Support dotted and dashed underline styles (#4529)
  * For the vertical and horizontal layouts have the windows
    arranged on a ring rather than a plane. This means the
    first and last window are considered neighbors (#4494)
  * A new action to clear the current selection (#4600)
  * Shell integration: fish: Fix cursor shape not working
    with fish’s vi mode (#4508)
  * Shell integration: fish: Dont override fish’s native
    title setting functionality. See discussion.
  * Draw the dots for braille characters more evenly spaced
    at all font sizes (#4499)
  * icat kitten: Add options to mirror images and remove
    their transparency before displaying them (#4513)
  * Fix getting last command output not working correctly
    when the screen is scrolled (#4522)
  * Show number of windows per tab in the select_tab action (#4523)
  * Fix clicking in a window to focus it and typingimmediately
    sometimes having unexpected effects if at a shell prompt (#4128)
  * themes kitten: Allow writing to a different file than kitty.conf.
* Fri Jan  7 2022 Michael Vetter <mvetter@suse.com>
- Update to 0.24.1:
  * Shell integration: Work around conflicts with some zsh plugins (#4428)
  * Have the zero width space and various other characters from the Other,
    formatting Unicode category be treated as combining characters (#4439)
  * Fix using --shell-integration with setup.py broken (#4434)
  * Fix showing debug information not working if kitty’s STDIN is
    not a tty (#4424)
  * Linux: Fix a regression that broke rendering of emoji with
    variation selectors (#4444)
* Fri Jan  7 2022 Michael Vetter <mvetter@suse.com>
- Update to 0.24.0:
  * Integrate kitty closely with common shells such as zsh, fish
    and bash. This allows lots of niceties such as jumping to
    previous prompts, opening the output of the last command in
    a new window, etc. See Shell integration for details.
    Packagers please read Notes for Linux/macOS packagers.
  * A new shortcut ctrl+shift+f7 to visually focus a window using
    the keyboard. Pressing it causes numbers to appear over each
    visible window and you can press the number to focus the
    corresponding window (#4110)
  * A new facility window_logo_path to draw an arbitrary PNG image
    as logo in the corner of a kitty window (#4167)
  * Allow rendering the cursor with a reverse video effect. See
    cursor for details (#126)
  * Allow rendering the mouse selection with a reverse video effect.
    See selection_foreground (#646)
  * A new option tab_bar_align to draw the tab bar centered or
    right aligned (#3946)
  * Allow the user to supply a custom Python function to draw tab bar.
    See tab_bar_style
  * A new remote control command to change the tab color
    <kitty @ set-tab-color> (#1287)
  * A new remote control command to visually select a window
    <kitty @ select-window> (#4165)
  * Add support for reporting mouse events with pixel co-ordinates
    using the SGR_PIXEL_PROTOCOL introduced in xterm 359
  * When programs ask to read from the clipboard prompt, ask the user
    to allow the request by default instead of denying it by
    default. See clipboard_control for details (#4022)
  * A new mappable action swap_with_window to swap the current
    window with another window in the tab, visually
  * A new remote control command <kitty @ set-enabled-layouts> to
    change the enabled layouts in a tab (#4129)
  * A new option bell_path to specify the path to a sound file to
    use as the bell sound
  * A new option exe_search_path to modify the locations kitty
    searches for executables to run (#4324)
  * broadcast kitten: Show a “fake” cursor in all windows being
    broadcast too (#4225)
  * Allow defining aliases for more general actions, not just
    kittens (#4260)
  * Fix a regression that caused kitty --title to not work when
    opening new OS windows using kitty --single-instance (#3893)
  * icat kitten: Fix display of JPEG images that are rotated via
    EXIF data and larger than available screen size (#3949)
  * Launch command: Allow specifying the OS window title
  * broadcast kitten: Allow broadcasting ctrl+c (#3956)
  * Fix space ligatures not working with Iosevka for some characters
    in the Enclosed Alphanumeric Supplement (#3954)
  * hints kitten: Fix a regression that caused using the default
    open program to trigger open actions instead of running the
    program (#3968)
  * Allow deleting environment variables in env by specifying just
    the variable name, without a value
  * Fix active_tab_foreground not being honored when tab_bar_style
    is slant (#4053)
  * When a tab_bar_background is specified it should extend to the
    edges of the OS window (#4054)
  * Linux: Fix IME with fcitx5 not working after fcitx5 is
    restarted (#4059)
  * Various improvements to IME integration (#4219)
  * Remote file transfer: Fix transfer not working if custom ssh
    port or identity is specified on the command line (#4067)
  * Unicode input kitten: Implement scrolling when more results
    are found than the available display space (#4068)
  * Allow middle clicking on a tab to close it (#4151)
  * The command line option --watcher has been deprecated in favor
    of the watcher option in kitty.conf. It has the advantage of
    applying to all windows, not just the initially created ones.
    Note that --watcher now also applies to all windows, not just
    initially created ones.
  * Backward incompatibility: No longer turn on the kitty extended
    keyboard protocol’s disambiguate mode when the client sends the
    XTMODKEYS escape code. Applications must use the dedicated
    escape code to turn on the protocol. (#4075)
  * Fix soft hyphens not being preserved when round tripping
    text through the terminal
  * Fix the resize OS Windows <kitty @ resize-os-window> setting
    a slightly incorrect size on high DPI screens (#4114)
  * kitty @ launch - when creating tabs with the --match option
    create the tab in the OS Window containing the result of the
    match rather than the active OS Window (#4126)
  * Linux X11: Add support for 10bit colors (#4150)
  * Fix various issues with changing tab_bar_background by remote
    control (#4152)
  * A new option tab_bar_margin_color to control the color of the
    tab bar margins
  * A new option visual_bell_color to customize the color of the
    visual bell (#4181)
  * Add support for OSC 777 based desktop notifications
  * Wayland: Fix pasting from applications that use a MIME type
    of “text/plain” rather than “text/plain;charset=utf-8”
    not working (#4183)
  * A new mappable action to close windows with a confirmation (#4195)
  * When remembering OS window sizes for full screen windows
    use the size before the window became fullscreen (#4221)
  * A new mappable action nth_os_window to to focus the specified
    nth OS window. (#4316)
* Wed Dec  8 2021 Franck Bui <fbui@suse.com>
- Fix the condition expressions that are used to build the
  doc. Currently we want the doc on TW only and disabled on Leap since
  sphinx has not been update yet (including in Leap 15.4).
- Fix build on TW
  * Dependency on python3-sphinx-inline-tabs was missing. It was
    needed to build the doc
- Fix build on Leap
  * python3-importlib-resources is named python3-importlib_resources
    on Leap :-/
- Rebased kitty-no-docs.patch
* Tue Aug 17 2021 Michael Vetter <mvetter@suse.com>
- Update to 0.23.1:
  * A new option clipboard_max_size to control the maximum size of
    data that kitty will transmit to the system clipboard on behalf
    of programs running inside it (#3937)
  * When matching windows/tabs in kittens or using remote control,
    allow matching by recency. recent:0 matches the active window/tab,
    recent:1 matches the previous window/tab and so on
  * themes kitten: Fix only the first custom theme file being
    loaded correctly (#3938)
* Mon Aug 16 2021 Michael Vetter <mvetter@suse.com>
- Update to 0.23.0:
  * A new themes kitten to easily change kitty themes. Choose
    from almost two hundred themes in the kitty themes repository
  * A new style for the tab bar that makes tabs looks like the tabs
    in a physical tabbed file, see tab_bar_style
  * Make the visual bell flash more gentle, especially on dark
    themes (#2937)
  * Fix kitty --title not overriding the OS Window title when
    multiple tabs are present. Also this option is no longer used
    as the default title for windows, allowing individual tabs/windows
    to have their own titles, even when the OS Window has a fixed
    overall title (#3893)
  * Linux: Fix some very long ligatures being rendered incorrectly
    at some font sizes (#3896)
  * Fix shift+middle click to paste sending a mouse press event
    but no release event which breaks some applications that grab
    the mouse but cant handle mouse events (#3902)
  * terminfo: Fix “cnorm” the property for setting the cursor to
    normal using a solid block rather than a blinking block
    cursor (#3906)
  * Add clear_all_mouse_actions to clear all mouse actions defined
    to that point (#3907)
  * Fix the remote file kitten not working when using – with ssh.
    The ssh kitten was recently changed to do this (#3929)
  * When dragging word or line selections, ensure the initially
    selected item is never deselected. This matches behavior in
    most other programs (#3930)
  * hints kitten: Make copy/paste with the kitty +kitten hints
  - -program option work when using the self kitty +kitten hints
  - -linenum-action (#3931)
* Mon Aug 16 2021 Michael Vetter <mvetter@suse.com>
- Update to 0.22.2:
  * Wayland: A better fix for compositors like sway that can toggle
    client side decorations on and off (#3888)
* Mon Aug 16 2021 Michael Vetter <mvetter@suse.com>
- Update to 0.22.1:
  * Fix a regression in the previous release that broke kitty
  - -help (#3869)
  * Graphics protocol: Fix composing onto currently displayed
    frame not updating the frame on the GPU (#3874)
  * Fix switching to previously active tab after detaching a
    tab not working (#3871)
  * detach_window: Allow specifying the previously active tab
    or the tab to the left/right of the active tab (#3877)
  * broadcast kitten: Fix a regression in 0.20.0 that broke
    sending of some keys, such as backspace
  * Linux binary: Remove any RPATH build artifacts from
    bundled libraries
  * Wayland: If the compositor turns off server side decorations
    after turning them on do not draw client side decorations (#3888)
* Mon Jul 26 2021 Michael Vetter <mvetter@suse.com>
- Update to 0.22.0:
  * Add a new toggle_layout action to easily zoom/unzoom a window
  * When right clicking to extend a selection, move the nearest
    selection boundary rather than the end of the selection. To restore
    previous behavior use mouse_map right press ungrabbed
    mouse_selection move-end.
  * When opening hyperlinks, allow defining open actions for directories (#3836)
  * When using the OSC 52 escape code to copy to clipboard allow large
    copies (up to 8MB) without needing a kitty specific chunking protocol.
    Note that if you used the chunking protocol in the past, it will no
    longer work and you should switch to using the unmodified protocol
    which has the advantage of working with all terminal emulators.
  * Fix a bug in the implementation of the synchronized updates escape code
    that could cause incorrect parsing if either the pending buffer
    capacity or the pending timeout were exceeded (#3779)
  * A new remote control command to resize the OS Window <kitty @ resize-os-window>
  * Graphics protocol: Add support for composing rectangles from one
    animation frame onto another (#3809)
  * diff kitten: Remove limit on max line length of 4096 characters (#3806)
  * Fix turning off cursor blink via escape codes not working (#3808)
  * Allow using neighboring window operations in the stack layout. The previous
    window is considered the left and top neighbor and the next window is
    considered the bottom and right neighbor (#3778)
  * Add a new variable {num_window_groups} for the tab_title_template (#3837)
  * Wayland: Fix initial_window_width/height specified in cells not working on
    High DPI screens (#3834)
  * A new theme for the kitty website with support for dark mode.
  * Render ┄ ┅ ┆ ┇ ┈ ┉ ┊ ┋ with spaces at the edges. Matches rendering in
    most other programs and allows long chains of them to look better (#3844)
  * hints kitten: Detect paths and hashes that appear over multiple lines. Note
    that this means that all line breaks in the text are no longer n soft breaks
    are instead r. If you use a custom regular expression that is meant to match
    over line breaks, you will need to match over both. (#3845)
  * Allow leading or trailing spaces in tab_activity_symbol
  * Fix mouse actions not working when caps lock or num lock are engaged (#3859)
  * clipboard kitten: fix copies to clipboard not working without the kitty +kitten
    clipboard --wait-for-completion option
* Mon Jun 28 2021 Michael Vetter <mvetter@suse.com>
- Update to 0.21.2:
  * A new adjust_baseline option to adjust the vertical alignment
    of text inside a line (#3734)
  * A new url_excluded_characters option to exclude additional
    characters when detecting URLs under the mouse (#3738)
  * Fix a regression in 0.21.0 that broke rendering of private use
    Unicode symbols followed by spaces, when they also exist not
    followed by spaces (#3729)
  * ssh kitten: Support systems where the login shell is a
    non-POSIX shell (#3405)
  * ssh kitten: Add completion (#3760)
  * ssh kitten: Fix "Connection closed" message being printed by
    ssh when running remote commands
  * Add support for the XTVERSION escape code
  * When displaying scrollback ensure that the window does not quit
    if the amount of scrollback is less than a screen and the user
    has the --quit-if-one-screen option enabled for less (#3740)
  * Linux: Fix Emoji/bitmapped fonts not use able in symbol_map
  * query terminal kitten: Allow querying font face and size
    information (#3756)
  * hyperlinked grep kitten: Fix context options not generating
    contextual output (#3759)
  * Allow using superscripts in tab titles (#3763)
  * Unicode input kitten: Fix searching when a word has more than
    1024 matches (#3773)
* Mon Jun 28 2021 Michael Vetter <mvetter@suse.com>
- Update to 0.21.2:
  * A new adjust_baseline option to adjust the vertical alignment
    of text inside a line (#3734)
  * A new url_excluded_characters option to exclude additional
    characters when detecting URLs under the mouse (#3738)
  * Fix a regression in 0.21.0 that broke rendering of private use
    Unicode symbols followed by spaces, when they also exist not
    followed by spaces (#3729)
  * ssh kitten: Support systems where the login shell is a
    non-POSIX shell (#3405)
  * ssh kitten: Add completion (#3760)
  * ssh kitten: Fix "Connection closed" message being printed by
    ssh when running remote commands
  * Add support for the XTVERSION escape code
  * When displaying scrollback ensure that the window does not quit
    if the amount of scrollback is less than a screen and the user
    has the --quit-if-one-screen option enabled for less (#3740)
  * Linux: Fix Emoji/bitmapped fonts not use able in symbol_map
  * query terminal kitten: Allow querying font face and size
    information (#3756)
  * hyperlinked grep kitten: Fix context options not generating
    contextual output (#3759)
  * Allow using superscripts in tab titles (#3763)
  * Unicode input kitten: Fix searching when a word has more than
    1024 matches (#3773)
* Mon Jun 14 2021 Michael Vetter <mvetter@suse.com>
- Update to 0.21.1:
  * Fix a regression in the previous release that could cause a
    crash when changing layouts and mousing (#3713)
* Mon Jun 14 2021 Michael Vetter <mvetter@suse.com>
- Update to 0.21.0:
  * Allow reloading the kitty.conf config file by pressing
    ctrl+shift+f5. (#1292)
  * Allow clicking URLs to open them without needing to also hold
    ctrl+shift
  * Allow remapping all mouse button press/release events to
    perform arbitrary actions. See details.
  * Support infinite length ligatures (#3504)
  * Backward incompatibility: The options to control which
    modifiers keys to press for various mouse actions have been
    removed, if you used these options, you will need to replace
    them with configuration using the new mouse actions framework
    as they will be ignored. The options were: terminal_select_modifiers,
    rectangle_select_modifiers and open_url_modifiers.
  * Add a configurable mouse action (ctrl+alt+triplepress to select
    from the clicked point to the end of the line. (#3585)
  * Add the ability to un-scroll the screen to the kitty @
    scroll-window remote control command (#3604)
  * A new option, tab_bar_margin_height to add margins around
    the top and bottom edges of the tab bar (#3247)
  * Unicode input kitten: Fix a regression in 0.20.0 that broke
    keyboard handling when the NumLock or CapsLock modifiers were engaged. (#3587)
  * Fix a regression in 0.20.0 that sent incorrect bytes for the
    F1-F4 keys in rmkx mode (#3586)
  * Add a few more special commandline arguments for the launch command.
    Now all KITTY_PIPE_DATA is also available via command line argument
    substitution (#3593)
  * Fix dynamically changing the background color in a window causing
    rendering artifacts in the tab bar (#3595)
  * Fix passing STDIN to launched background processes causing them to
    not inherit environment variables (#3603)
  * Fix deleting windows that are not the last window via remote control
    leaving no window focused (#3619)
  * Add an option kitty @ get-text --add-cursor to also get the current
    cursor position and state as ANSI escape codes (#3625)
  * Add an option kitty @ get-text --add-wrap-markers to add line wrap
    markers to the output (#3633)
  * Improve rendering of curly underlines on HiDPI screens (#3637)
  * ssh kitten: Mimic behavior of ssh command line client more closely
    by executing any command specified on the command line via the users'
    shell just as ssh does (#3638)
  * Fix trailing parentheses in URLs not being detected (#3688)
  * Tab bar: Use a lower contrast color for tab separators (#3666)
  * Fix a regression that caused using the title command in session
    files to stop working (#3676)
  * Fix ligatures not working with the Iosevka font
    (requires Iosevka >= 7.0.4) (#297)
  * Remote control: Allow matching tabs by index number in currently
    active OS Window (#3708)
  * ssh kitten: Fix non-standard properties in terminfo such as the
    ones used for true color not being copied (#312)
- Add BR python-sphinxcontrib-copybutton
* Thu May  6 2021 Michael Vetter <mvetter@suse.com>
- Update to 0.20.3:
  * A new show_key kitten to easily see the bytes generated by the
    terminal for key presses in the various keyboard modes (#3556)
  * Linux: Fix keyboard layout change keys defined via compose
    rules not being ignored
  * Fix tab activity symbol not appearing if no other changes happen
    in tab bar even when there is activity in a tab (#3571)
  * Fix focus changes not being sent to windows when focused window
    changes because of the previously focused window being
    closed (#3571)
* Wed Apr 28 2021 Michael Vetter <mvetter@suse.com>
- Update to 0.20.2:
  * A new protocol extension to unscroll text from the scrollback
    buffer onto the screen. Useful, for example, to restore the
    screen after showing completions below the shell prompt.
  * A new remote control command kitty @ env to change the default
    environment passed to newly created windows (#3529)
  * Linux: Fix binary kitty builds not able to load fonts in WOFF2
    format (#3506)
  * Fix kitty @ close-tab not working with pipe based remote
    control (#3510)
  * Fix removal of inactive tab that is before the currently
    active tab causing the highlighted tab to be incorrect (#3516)
  * icat kitten: Respect EXIF orientation when displaying
    JPEG images (#3518)
  * GNOME: Fix maximize state not being remembered when focus
    changes and window decorations are hidden (#3507)
  * GNOME: Add a new wayland_titlebar_color option to control
    the color of the kitty window title bar
  * Fix reading kitty --session from STDIN not working when the
    kitty --detach option is used (#3523)
  * Special case rendering of the few remaining Powerline box
    drawing chars (#3535)
  * Fix kitty @ set-colors not working for the active_tab_foreground.
* Mon Apr 19 2021 Michael Vetter <mvetter@suse.com>
- Update to 0.20.1:
  * icat: Fix some broken GIF images with no frame delays not
    being animated (#3498)
  * hints kitten: Fix sending hyperlinks to their default
    handler not working (#3500)
  * Wayland: Fix regression in previous release causing window
    decorations to be drawn even when compositor supports server
  side decorations (#3501)
* Mon Apr 19 2021 Michael Vetter <mvetter@suse.com>
- Update to 0.20.0:
  * Support display of animated images kitty +kitten icat animation.gif.
    See Animation for details on animation support in the kitty graphics protocol.
  * A new keyboard reporting protocol with various advanced features
    that can be used by full screen terminal programs and even games,
    see A protocol for comprehensive keyboard handling in terminals (#3248)
  * Backward incompatibility: Session files now use the full launch command
    with all its capabilities. However, the syntax of the command is slightly
    different from before. In particular watchers are now specified directly
    on launch and environment variables are set using --env.
  * Allow setting colors when creating windows using the launch command.
  * A new option tab_powerline_style to control the appearance of the tab
    bar when using the powerline tab bar style.
  * A new option scrollback_fill_enlarged_window to fill extra lines in the
    window when the window is expanded with lines from the scrollback (#3371)
  * diff kitten: Implement recursive diff over SSH (#3268)
  * ssh kitten: Allow using python instead of the shell on the server,
    useful if the shell used is a non-POSIX compliant one, such as fish (#3277)
  * Add support for the color settings stack that XTerm copied from us
    without acknowledgement and decided to use incompatible escape codes for.
  * Add entries to the terminfo file for some user capabilities that are
    shared with XTerm (#3193)
  * The launch command now does more sophisticated resolving of executables to run.
    The system-wide PATH is used first, then system specific default paths,
    and finally the PATH inside the shell.
  * Double clicking on empty tab bar area now opens a new tab (#3201)
  * kitty @ ls: Show only environment variables that are different for each window, by default.
  * When passing a directory or a non-executable file as the program to run to kitty
    opens it with the shell or by parsing the shebang, instead of just failing.
  * Linux: Fix rendering of emoji followed by the graphics variation selector
    not being colored with some fonts (#3211)
  * Unicode input: Fix using index in select by name mode not working for indices
    larger than 16. Also using an index does not filter the list of matches. (#3219)
  * Wayland: Add support for the text input protocol (#3410)
  * Wayland: Fix mouse handling when using client side decorations
  * Wayland: Fix un-maximizing a window not restoring its size to what it was
    beforebeing maximized
  * GNOME/Wayland: Improve window decorations the titlebar now shows the window title.
    Allow running under Wayland on GNOME by default. (#3284)
  * Panel kitten: Allow setting WM_CLASS (#3233)
  * Also detect gemini:// URLs when hovering with the mouse (#3370)
  * When using a non-US keyboard layout and pressing ctrl+key when the key
    matches an English key, send that to the program running in the terminal
    automatically (#2000)
  * When matching shortcuts, also match on shifted keys, so a shortcut defined as
    ctrl+plus will match a keyboard where you have to press shift+equal to get
    the plus key (#2000)
  * Fix extra space at bottom of OS window when using the fat layout with the tab
    bar at the top (#3258)
  * Fix window icon not working on X11 with 64bits (#3260)
  * Fix OS window sizes under 100px resulting in scaled display (#3307)
  * Fix rendering of ligatures in the latest release of Cascadia code, which for
    some reason puts empty glyphs after the ligature glyph rather than before it (#3313)
  * Improve handling of infinite length ligatures in newer versions of FiraCode
    and CascadiaCode. Now such ligatures are detected based on glyph naming convention.
    This removes the gap in the ligatures at cell boundaries (#2695)
  * hints kitten: When using the linenumber action with a background action,
    preserve the working directory (#3352)
  * Graphics protocol: Fix suppression of responses not working for chunked transmission (#3375)
  * Fix inactive tab closing causing active tab to change (#3398)
  * Fix a crash on systems using musl as libc (#3395)
  * Improve rendering of rounded corners by using a rectircle equation rather than a cubic bezier (#3409)
  * Graphics protocol: Add a control to allow clients to specify that the cursor should
    not move when displaying an image (#3411)
  * Fix marking of text not working on lines that contain zero cells (#3403)
  * Fix the selection getting changed if the screen contents scroll while the selection is in progress (#3431)
  * X11: Fix resize_in_steps being applied even when window is maximized (#3473)
* Fri Apr 16 2021 Michael Vetter <mvetter@suse.com>
- Fix build on Factory:
  kitty does not properly separate build and install. We used to
  do both in the %%build section. Since rpm 4.16 cleans the buildroot
  is cleaned before %%install. So now we run build/install in the
  %%install section
* Mon Dec 28 2020 Michael Vetter <mvetter@suse.com>
- Update to 0.19.3:
  * A new broadcast kitten to type in all kitty windows
    simultaneously (#1569)
  * Add a new mappable select_tab action to choose a tab to switch
    to even when the tab bar is hidden (#3115)
  * Allow specifying text formatting in tab_title_template (#3146)
  * Linux: Read font_features from the FontConfig database as well,
    so that they can be configured in a single, central location (#3174)
  * Graphics protocol: Add support for giving individual image
    placements their own ids and for asking the terminal emulator to
    assign ids for images. Also allow suppressing responses from the
    terminal to commands. These are backwards compatible protocol
    extensions. (#3133, #3163)
  * Distribute extra pixels among all eight-blocks rather than adding
    them all to the last block (#3097)
  * Fix drawing of a few sextant characters incorrect (#3105)
  * Preserve lines in the scrollback if a scrolling region is defined
    that is contiguous with the top of the screen (#3113)
  * Wayland: Fix key repeat being stopped by the release of an
    unrelated key (#2191)
  * Add an option, detect_urls to control whether kitty will detect
    URLs when the mouse moves over them (#3118)
  * Graphics protocol: Dont return filename in the error message when
    opening file fails, since filenames can contain control characters (#3128)
  * Fix one ANSI formatting escape code not being removed from the
    pager history buffer when piping it as plain text (#3132)
  * Match the save/restore cursor behavior of other terminals, for the
    sake of interoperability. This means that doing a DECRC without a
    prior DECSC is now undefined (#1264)
  * Fix mapping remote_control send-text not working (#3147)
  * Add a right option for tab_switch_strategy (#3155)
  * Fix a regression in 0.19.0 that caused a rare crash when using the
    optional scrollback_pager_history_size (#3049)
  * Full screen kittens: Fix incorrect cursor position after
    kitten quits (#3176)
- Fix bsc#1180298 CVE-2020-35605
* Mon Nov 16 2020 Avindra Goolcharan <avindra@opensuse.org>
- Update to 0.19.2:
  * A new Query terminal kitten to easily query the running kitty
    via escape codes to detect its version, and the values of
    configuration options that enable or disable terminal features.
  * Options to control mouse pointer shape, default_pointer_shape,
    and pointer_shape_when_dragging
  * Font independent rendering for braille characters, which
    ensures they are properly aligned at all font sizes.
  * Fix a regression in 0.19.0 that caused borders not to be drawn
    when setting window_margin_width and keeping
    draw_minimal_borders on
  * Fix a regression in 0.19.0 that broke rendering of one-eight
    bar unicode characters at very small font sizes
  * Wayland: Fix a crash under GNOME when using multiple OS windows
  * Fix selections created by dragging upwards not being
    auto-cleared when screen contents change
  * Allow adding MIME definitions to kitty by placing a mime.types
    file in the kitty config directory
  * Dont ignore --title when using a session file that defines
    no windows
  * Fix the send_text action not working in URL handlers
  * Fix last character of URL not being detected if it is the only
    character on a new line
  * Don't restrict the ICH,DCH,REP control codes to only the
    current scroll region
- use generic name in rpm files section
* Tue Oct  6 2020 Michael Vetter <mvetter@suse.com>
- Update to 0.19.1:
  * hints kitten: Add an ip type for easy selection of IP addresses (#3009)
  * Fix a regression that caused a segfault when using
    scrollback_pager_history_size and it needs to be expanded (#3011)
  * Fix update available notifications repeating (#3006)
* Mon Oct  5 2020 Michael Vetter <mvetter@suse.com>
- Update to 0.19.0:
  * Add support for hyperlinks from terminal programs. Controlled
    via allow_hyperlinks (#68)
  * Add support for easily editing or downloading files over SSH
    sessions without the need for any special software
  * A new Hyperlinked grep kitten to easily search files and open
    the results at the matched line by clicking on them.
  * Allow customizing the actions kitty takes when clicking on URLs
  * Improve rendering of borders when using minimal borders.
    Use less space and do not display a box around active windows
  * Add a new extensible escape code to allow terminal programs to
    trigger desktop notifications. See Desktop notifications (#1474)
  * Implement special rendering for various characters from the set
    of "Symbols for Legacy Computing" from the Unicode 13 standard
  * Unicode input kitten: Allow choosing symbols from the NERD font
    as well. These are mostly Private Use symbols not in any standard,
    however are common. (#2972)
  * Allow specifying border sizes in either pts or pixels. Change the
    default to 0.5pt borders as this works best with the new minimal border style
  * Add support for displaying correct colors with non-sRGB PNG
    files (Adds a dependency on liblcms2)
  * hints kitten: Add a new kitty +kitten hints --type of hyperlink useful
    for activating hyperlinks using just the keyboard
  * Allow tracking focus change events in watchers (#2918)
  * Allow specifying watchers in session files and via a
    command line argument (#2933)
  * Add a setting tab_activity_symbol to show a symbol in the tab title if
    one of the windows has some activity after it was last focused (#2515)
  * When in the main screen and a program grabs the mouse, do not use the
    scroll wheel events to scroll the scrollback buffer, instead send
    them to the program (#2939)
  * Fix unfocused windows in which a bell occurs not changing their border color
    to red until a relayout
  * Linux: Fix automatic detection of bold/italic faces for fonts such as IBM
    Plex Mono that have the regular face with a full name that is the same as
    the family name (#2951)
  * Fix a regression that broke kitten_alias (#2952)
  * Fix a regression that broke the move_window_to_top action (#2953)
  * Fix a memory leak when changing font sizes
  * Fix some lines in the scrollback buffer not being properly rendered after a
    window resize/font size change (#2619)
* Wed Sep 23 2020 Ondřej Súkup <mimi.vx@gmail.com>
- kitty doesn't use libexecdir
* Wed Aug 12 2020 Michael Vetter <mvetter@suse.com>
- Update to 0.18.3:
  * hints kitten: Allow customizing hint colors (#2894)
  * Wayland: Fix a typo in the previous release that broke reading
    mouse cursor size (#2895)
  * Fix a regression in the previous release that could cause an
    exception during startup in rare circumstances (#2896)
  * Fix image leaving behind a black rectangle when switch away and
    back to alternate screen (#2901)
  * Fix one pixel mis-alignment of rounded corners when either the
    cell dimensions or the thickness of the line is an odd number
    of pixels (#2907)
  * Fix a regression that broke specifying OS window size in the
    session file (#2908)
* Wed Jul 29 2020 Michael Vetter <mvetter@suse.com>
- Update to 0.18.2:
  * X11: Improve handling of multiple keyboards. Now pressing a
    modifier key in one keyboard and a normal key in another works (#2362).
    Don't rebuild keymaps on new keyboard events that only change
    geometry (#2787). Better handling of multiple keyboards with
    incompatible layouts (#2726)
  * Improve anti-aliasing of triangular box drawing characters,
    noticeable on low-resolution screens (#2844)
  * Fix kitty @ send-text not working reliably when using a socket
    for remote control (#2852)
  * Implement support for box drawing rounded-corners characters (#2240)
  * Allow setting the class for new OS windows in a session file
  * When a character from the Unicode Dingbat block is followed by a
    space, use the extra space to render a larger version of the character (#2850)
  * Make neighboring window selection in grid and splits layouts
    more intelligent (#2840)
  * Allow passing the current selection to kittens (#2796)
  * Fix pre-edit text not always being cleared with ibus input (#2862)
  * Allow setting the background_opacity of new OS windows created via
    kitty --single-instance using the kitty --override command line argument (#2806)
  * Fix the CSI J (Erase in display ED) escape code not removing line
    continued markers (#2809)
  * hints kitten: In linenumber mode expand paths that starts with ~ (#2822)
  * Fix launch --location=last not working (#2841)
  * Fix incorrect centering when a PUA or symbol glyph is followed by
    more than one space
  * Have the confirm_os_window_close option also apply when closing tabs
    with multiple windows (#2857)
  * Add support for legacy DECSET codes 47, 1047 and 1048 (#2871)
  * Wayland: Fix a regression in 0.18.0 that could cause crashes related
    to mouse cursors in some rare circumstances (#2810)
  * Fix change in window size that does not change number of cells not being
    reported to the kernel (#2880)
* Fri Jun 26 2020 Philipp Seiler <p.seiler@linuxmail.org>
- ported no-docs patch to 0.18.1
- improved the sed line and added another one for python2
* Wed Jun 24 2020 Michael Vetter <mvetter@suse.com>
- Update to 0.18.1:
  * macOS: Fix for diff kitten not working with python 3.8 (#2780)
* Mon Jun 22 2020 Michael Vetter <mvetter@suse.com>
- Update to 0.18.0:
  * Allow multiple overlay windows per normal window
  * Add an option confirm_os_window_close to ask for confirmation when
    closing an OS window with multiple kitty windows.
  * Tall and Fat layouts: Add a mirrored option to put the full size
    window on the opposite edge of the screen (#2654)
  * Tall and Fat layouts: Add mappable actions to increase or
    decrease the number of full size windows (#2688)
  * Allow sending arbitrary signals to the current foreground process
    in a window using either a mapping in kitty.conf or via remote
    control (#2778)
  * Allow sending the back and forward mouse buttons to terminal
    applications (#2742)
  * Backwards incompatibility: The numbers used to encode mouse
    buttons for the send_mouse_event function that can be used in
    kittens have been changed (see Sending mouse events).
  * Add a new mappable quit action to quit kitty completely.
  * Fix marks using different colors with regexes using only
    a single color (#2663)
  * Linux: Workaround for broken Nvidia drivers for old cards (#456)
  * Wayland: Fix kitty being killed on some Wayland compositors
    if a hidden window has a lot of output (#2329)
  * Add support for the CSI REP escape code (#2702)
  * Wayland: Fix mouse cursor rendering on HiDPI screens (#2709)
  * X11: Recompile keymaps on XkbNewKeyboardNotify events (#2726)
  * X11: Reduce startup time by ~25%% by only querying GLX for
    framebuffer configurations once (#2754)
  * Fix the kitty shell launched via a mapping needlessly requiring
    allow_remote_control to be turned on.
* Mon May 11 2020 Michael Vetter <mvetter@suse.com>
- Update to 0.17.4:
  * Allow showing the name of the current layout and the number of
    windows in tab titles (#2634)
  * By default, double clicking no longer considers the : as part
    of words, see select_by_word_characters (#2602)
  * Fix a regression that caused clicking in the padding/margins
    of windows in the stack layout to switch the window to the
    first window (#2604)
  * Report modifier key state when sending wheel events to the
    terminal program
  * Fix kitty @ send-text not working with text larger than 1024
    bytes when using kitty --listen-on (#2607)
  * Wayland: Fix OS window title not updating for hidden
    windows (#2629)
  * Fix background_tint making the window semi-transparent (#2618)
* Thu Apr 23 2020 Michael Vetter <mvetter@suse.com>
- Update to 0.17.3:
  * Allow individually setting margins and padding for each edge
    (left, right, top, bottom). Margins can also be controlled per
    window via remote control (#2546)
  * Fix reverse video not being rendered correctly when using
    transparency or a background image (#2419)
  * Allow mapping arbitrary remote control commands to key
    presses in kitty.conf
  * X11: Fix crash when doing drag and drop from some
    applications (#2505)
  * Fix launch --stdin-add-formatting not working (#2512)
  * Update to Unicode 13.0 (#2513)
  * Render country flags designated by a pair of unicode
    codepoints in two cells instead of four.
  * diff kitten: New option to control the background color for
    filler lines in the margin (#2518)
  * Fix specifying options for layouts in the startup session
    file not working (#2520)
  * Linux: Ignore keys if they are designated as
    layout/group/mode switch keys (#2519)
  * Marks: Fix marks not handling wide characters and tab
    characters correctly (#2534)
  * Add a new listen_on option in kitty.conf to set kitty
  - -listen-on globally. Also allow using environment
    variables in this option (#2569).
  * Allow sending mouse events in kittens (#2538)
  * icat kitten: Fix display of 16-bit depth images (#2542)
  * Add ncurses specific terminfo definitions for
    strikethrough (#2567)
  * Fix a regression in 0.17 that broke displaying graphics
    over SSH (#2568)
  * Fix --title not being applied at window creation time (#2570)
* Sun Mar 29 2020 Michael Vetter <mvetter@suse.com>
- Update to 0.17.2:
  * Add a launch --watcher option that allows defining callbacks
    that are called for various events in the window's life-cycle
    (#2440)
  * Fix a regression in 0.17 that broke drawing of borders with
    non-minimal borders (#2474)
  * Hints kitten: Allow copying to primary selection as well
    as clipboard (#2487)
  * Add a new mappable action close_other_windows_in_tab to close
    all but the active window (#2484)
  * Hints kitten: Adjust the default regex used to detect line
    numbers to handle line+column numbers (#2268)
  * Fix blank space at the start of tab bar in the powerline
    style when first tab is inactive (#2478)
  * Fix regression causing incorrect rendering of separators in
    tab bar when defining a tab bar background color (#2480)
  * Fix a regression in 0.17 that broke the kitty @ launch remote
    command and also broke the --tab-title option when
    creating a new tab. (#2488)
  * Linux: Fix selection of fonts with multiple width variants
    not preferring the normal width faces (#2491)
* Thu Mar 26 2020 Michael Vetter <mvetter@suse.com>
- Update to 0.17.1:
  * Fix cursor_underline_thickness not working (#2465)
  * Fix a regression in 0.17 that caused tab bar background to be
    rendered after the last tab as well (#2464)
  * Fix a regression in 0.17 that caused kitty @ set-colors to
    require setting cursor_text_color (#2470)
* Tue Mar 24 2020 Michael Vetter <mvetter@suse.com>
- Update to 0.17.0:
  * A new The Splits Layout to arrange windows in arbitrary splits (#2308)
  * Add support for specifying a background image, see background_image
    (#163 and #2326; thanks to Fredrick Brennan.)
  * A new background_tint option to darken the background under the
    text area when using background images and/or transparent windows.
  * Allow selection of single cells with the mouse. Also improve mouse
    selection to follow semantics common to most programs (#945)
  * New options cursor_beam_thickness and cursor_underline_thickness
    to control the thickness of the beam and underline cursors (#2337 and #2342)
  * When the application running in the terminal grabs the mouse, pass
    middle clicks to the application unless terminal_select_modifiers
    are pressed (#2368)
  * A new copy_and_clear_or_interrupt function (#2403)
  * X11: Fix arrow mouse cursor using right pointing instead of the
    default left pointing arrow (#2341)
  * Allow passing the currently active kitty window id in the launch command (#2391)
  * unicode input kitten: Allow pressing ctrl+tab to change the input mode (#2343)
  * Fix a bug that prevented using custom functions with the new marks feature (#2344)
  * Make the set of URL prefixes that are recognized while hovering with the
    mouse configurable (#2416)
  * Fix border/margin/padding sizes not being recalculated on DPI change (#2346)
  * diff kitten: Fix directory diffing with removed binary files failing (#2378)
  * Fix rendering of combining characters with fonts that have glyphs for
    precomposed characters but not decomposed versions (#2365)
  * Fix incorrect rendering of selection when using rectangular select and
    scrolling (#2351)
  * Allow setting WM_CLASS and WM_NAME when creating new OS windows
    with the launch command (launch --os-window-class)
  * Fix a regression in the previous release that broke switching to
    neighboring windows in the Grid layout when there are less
    than four windows (#2377)
  * Fix colors in scrollback pager off if the window has redefined
    terminal colors using escape codes (#2381)
  * Fix selection not updating properly while scrolling (#2442)
  * Allow extending selections by dragging with right button pressed (#2445)
  * Workaround for bug in less that causes colors to reset at wrapped lines (#2381)
  * X11/Wayland: Allow drag and drop of text/plain in addition to text/uri-list (#2441)
  * Dont strip & and - from the end of URLs (#2436)
  * Fix @selection placeholder not working with launch command (#2417)
  * Drop support for python 3.5
  * Wayland: Fix a crash when drag and dropping into kitty (#2432)
  * diff kitten: Fix images lingering as blank rectangles after the kitten quits (#2449)
  * diff kitten: Fix images losing position when scrolling using mouse wheel/touchpad
* Tue Jan 28 2020 Martin Rey <mrey@suse.com>
- Update to 0.16.0:
  * A new Marks feature that allows highlighting and scrolling to
    arbitrary text in the terminal window.
  * hints kitten: Allow pressing ctrl+shift+p>n to quickly open the
    selected file at the selected line in vim or a configurable
    editor (#2268)
  * Allow having more than one full height window in the tall
    layout (#2276)
  * Allow choosing OpenType features for individual fonts via the
    font_features option. (#2248)
  * Wayland: Fix a freeze in rare circumstances when having
    multiple OS Windows (#2307 and #1722)
  * Wayland: Fix window titles being set to very long strings on
    the order of 8KB causing a crash (#1526)
  * Add an option force_ltr to turn off the display of text in RTL
    scripts in right-to-left order (#2293)
  * Allow opening new tabs/windows before the current tab/window as
    well as after it with the launch --location option.
  * Add a resize_in_steps option that can be used to resize the OS
    window in steps as large as character cells (#2131)
  * When triple-click+dragging to select multiple lines, extend the
    selection of the first line to match the rest on the left
    (#2284)
  * Fix a segfault when using kitty --debug-config with maps
    (#2270)
  * goto_tab now maps numbers larger than the last tab to the last
    tab (#2291)
  * Fix URL detection not working for urls of the form
    scheme:///url (#2292)
  * When windows are semi-transparent and all contain graphics,
    correctly render them. (#2310)
* Fri Dec 27 2019 Michael Vetter <mvetter@suse.com>
- Update to 0.15.1:
  * Fix a crash/incorrect rendering when detaching a window in
    some circumstances (#2173)
  * hints kitten: Add an option kitty +kitten hints --ascending
    to control if the hints numbers increase or decrease from
    top to bottom
  * Fix background_opacity incorrectly applying to selected
    text and reverse video text (#2177)
  * Add a new option tab_bar_background to specify a different
    color for the tab bar (#2198)
  * Add a new option active_tab_title_template to specify a
    different template for active tab titles (#2198)
  * Fix lines at the edge of the window at certain windows sizes
    when drawing images on a transparent window (#2079)
  * Fix window not being rendered for the first time until some
    input has been received from child process (#2216)
* Wed Nov 27 2019 Michael Vetter <mvetter@suse.com>
- Update to 0.15.0:
  * Add a new action detach_window that can be used to move the current window
    into a different tab (#1310)
  * Add a new action launch that unifies launching of processes in new kitty
    windows/tabs.
  * Add a new style powerline for tab bar rendering, see tab_bar_style (#2021)
  * Allow changing colors by mapping a keyboard shortcut to read a kitty config
    file with color definitions. See the FAQ for details (#2083)
  * hints kitten: Allow completely customizing the matching and actions
    performed by the kitten using your own script (#2124)
  * Wayland: Fix key repeat not being stopped when focus leaves window. This is
    expected behavior on Wayland, apparently (#2014)
  * When drawing unicode symbols that are followed by spaces, use multiple
    cells to avoid resized or cut-off glyphs (#1452)
  * diff kitten: Allow diffing remote files easily via ssh (#727)
  * unicode input kitten: Add an option kitty +kitten unicode_input
  - -emoji-variation to control the presentation variant of selected emojis
    (#2139)
  * Add specialised rendering for a few more box powerline and unicode symbols
    (#2074 and #2021)
  * Add a new socket only mode for allow_remote_control. This makes it possible
    for programs running on the local machine to control kitty but not programs
    running over ssh.
  * hints kitten: Allow using named groups in the regular expression. The named
    groups are passed to the invoked program for further processing.
  * Fix a regression in 0.14.5 that caused rendering of private use glyphs with
    and without spaces to be identical (#2117)
  * Wayland: Fix incorrect scale used when first creating an OS window (#2133)
* Mon Sep 30 2019 mvetter@suse.com
- Update to 0.14.6:
  * Fix a regression in the previous release that caused kitty to
    not always respond to DPI changes (#1999)
- Changes from 0.14.5:
  * Implement a hack to (mostly) preserve tabs when cat-ting a
    file with them and then copying the text or passing screen
    contents to another program (#1829)
  * When all visible windows have the same background color, use
    that as the color for the global padding, instead of the
    configured background color (#1957)
  * When resetting the terminal, also reset parser state, this
    allows easy recovery from incomplete escape codes (#1961)
  * Allow mapping keys commonly found on European keyboards (#1928)
  * Fix incorrect rendering of some symbols when followed by a
    space while using the PowerLine font which does not have a
    space glyph (#1225)
  * Linux: Allow using fonts with spacing=90 in addition to
    fonts with spacing=100 (#1968)
  * Use selection foreground color for underlines as well (#1982)
* Mon Sep  2 2019 mvetter@suse.com
- Update to 0.14.4:
  * hints kitten: Add a kitty +kitten hints --alphabet option to
    control what alphabets are used for hints (#1879)
  * hints kitten: Allow specifying kitty +kitten hints --program
    multiple times to run multiple programs (#1879)
  * Add a kitten_alias option that can be used to alias kitten
    invocation for brevity and to change kitten option defaults globally (#1879)
  * When running kittens, use the colorscheme of the current window
    rather than the configured colorscheme (#1906)
  * Don't fail to start if running the shell to read the EDITOR
    env var fails (#1869)
  * Disable the liga and dlig OpenType features for broken
    fonts such as Nimbus Mono.
  * Fix a regression that broke setting background_opacity
    via remote control (#1895)
  * Fix piping PNG images into the icat kitten not working (#1920)
  * When the OS returns a fallback font that does not actually
    contain glyphs for the text, do not exhaust the list of fallback fonts (#1918)
  * Fix formatting attributes not reset across line boundaries
    when passing buffer as ANSI (#1924)
* Mon Jul 29 2019 mvetter@suse.com
- Update to 0.14.3:
  * Remote control: Add a command kitty @ scroll-window to scroll windows
  * Allow passing a !neighbor argument to the new_window mapping to open
    a new window next to the active window (#1746)
  * Document the kitty remote control protocol (#1646)
  * Add a new option pointer_shape_when_grabbed that allows you to control
    the mouse pointer shape when the terminal programs grabs the pointer (#1808)
  * Add an option terminal_select_modifiers to control which modifiers are
    used to override mouse selection even when a terminal application has
    grabbed the mouse (#1774)
  * When piping data to a child in the pipe command do it in a thread so as
    not to block the UI (#1708)
  * unicode_input kitten: Fix a regression that broke using indices to select
    recently used symbols.
  * Fix a regression that caused closing an overlay window to focus the previously
    focused window rather than the underlying window (#1720)
  * Linux: Fix incorrect scaling for fallback fonts when the font has an underscore
    that renders out of bounds (#1713)
  * Fix an out of bounds read causing a crash when selecting text with the mouse
    in the alternate screen mode (#1578)
  * Linux: Use the system "bell" sound for the terminal bell. Adds libcanberra as a
    new dependency to play the system sound.
  * Linux: Fix a regression in 0.14.0 that caused the event loop to tick continuously,
    wasting CPU even when idle (#1782)
  * ssh kitten: Make argument parsing more like ssh (#1787)
  * When using strip_trailing_spaces do not remove empty lines (#1802)
  * Fix a crash when displaying very large number of images (#1825)
* Wed Jun 26 2019 Ondřej Súkup <mimi.vx@gmail.com>
- enable build of doc for Leap 15.1+
* Tue Jun 11 2019 mvetter@suse.com
- Update to 0.14.2:
  * Add an option placement_strategy to control how the cell area is aligned inside the window when the window size is not an exact multiple of the cell size (#1670)
  * hints kitten: Add a kitty +kitten hints --multiple-joiner option to control how multiple selections are serialized when copying to clipboard or inserting into the terminal. You can have them on separate lines, separated by arbitrary characters, or even serialized as JSON (#1665)
  * panel kitten: Fix the contents of the panel kitten not being positioned correctly on the vertical axis
  * icat kitten: Fix a regression that broke passing directories to icat (#1683)
  * clipboard kitten: Add a kitty +kitten clipboard --wait-for-completion option to have the kitten wait till copying to clipboard is complete (#1693)
  * Allow using the pipe command to send screen and scrollback contents directly to the clipboard (#1693)
  * Linux: Disable the Wayland backend on GNOME by default as GNOME has no support for server side decorations. Can be controlled by linux_display_server.
  * Add an option to control the default update_check_interval when building kitty packages
  * Wayland: Fix resizing the window on a compositor that does not provide server side window decorations, such a GNOME or Weston not working correctly (#1659)
  * Wayland: Fix crash when enabling disabling monitors on sway (#1696)
* Thu May 30 2019 Michael Vetter <mvetter@suse.com>
- Update to 0.14.1:
  * Add an option command_on_bell to run an arbitrary command when a bell occurs (#1660)
  * Add a shortcut to toggle maximized window state ctrl+shift+f10
  * Add support for the underscore key found in some keyboard layouts (#1639)
  * Fix a missing newline when using the pipe command between the scrollback and screen contents (#1642)
  * Fix colors not being preserved when using the pipe command with the pager history buffer (#1657)
  * When resizing and only a single window is present in the current layout, use that window's background color to fill in the blank areas.
  * Linux: Automatically increase cell height if the font being used is broken and draws the underscore outside the bounding box (#690)
  * Wayland: Fix maximizing the window on a compositor that does not provide server side window decorations, such a GNOME or Weston not working (#1662)
- Update kitty-no-docs.patch
* Fri May 24 2019 mvetter@suse.com
- Update to 0.14.0:
  * Support for an arbitrary number of internal clipboard buffers to copy/paste from, see (Multiple copy/paste buffers)
  * Allow using the new private internal clipboard buffers with the copy_on_select option (#1390)
  * Add an option disable_ligatures to disable multi-character ligatures under the cursor to make editing easier or disable them completely (#461)
  * Allow creating new OS windows in session files (#1514)
  * Allow setting OS window size in session files
  * Add an option tab_switch_strategy to control which tab becomes active when the current tab is closed (#1524)
  * Allow specifying a value of none for the selection_foreground which will cause kitty to not change text color in selections (#1358)
  * Make live resizing of OS windows smoother and add an option resize_draw_strategy to control what is drawn while a resize is in progress.
  * When a window is closed, switch focus to the previously active window (if any) instead of picking the previous window in the layout (#1450)
  * icat kitten: Add support for displaying images at http(s) URLs (#1340)
  * A new option strip_trailing_spaces to optionally remove trailing spaces from lines when copying to clipboard.
  * A new option tab_bar_min_tabs to control how many tabs must be present before the tab-bar is shown (#1382)
  * Automatically check for new releases and notify when an update is available, via the system notification facilities. Can be controlled by update_check_interval (#1342)
  * Fix using remote control to set cursor text color causing errors when creating new windows (#1326)
  * Fix window title for minimized windows not being updated (#1332)
  * Fix scrollback pager history not being cleared when clearing the main scrollback buffer (#1387)
  * Wayland: Use the kitty Wayland backend by default. Can be switched back to using XWayland by setting the environment variable: KITTY_DISABLE_WAYLAND=1
  * Add a no-append setting to clipboard_control to disable the kitty copy concatenation protocol extension for OSC 52.
  * Update to using the Unicode 12 standard
  * Unicode input kitten: Allow using the arrow keys in code mode to go to next and previous unicode symbol.
  * Fix a regression in version 0.13.0 that caused background colors of space characters after private use unicode characters to not be respected (#1455)
  * Only update the selected text to clipboard when the selection is finished, not continuously as it is updated. (#1460)
  * Allow setting active_border_color to none to not draw a border around the active window (#805)
  * Use negative values for mouse_hide_wait to hide the mouse cursor immediately when pressing a key (#1534)
  * When encountering errors in kitty.conf report them to the user instead of failing to start.
  * Allow the user to control the resize debounce time via resize_debounce_time.
  * Remote control: Make the kitty @ set-font-size command more capable. It can now increment font size and reset it. It also only acts on the active top-level window, by default (#1581)
  * When launching child processes set the PWD environment variable (#1595)
  * X11: use the window manager's native full-screen implementation when making windows full-screen (#1605)
  * Mouse selection: When extending by word, fix extending selection to non-word characters not working well (#1616)
* Sat Apr 20 2019 Jan Engelhardt <jengelh@inai.de>
- Trim metadata redundancies and bias from descriptions.
* Tue Jan 22 2019 mvetter@suse.com
- Update to 0.13.3:
  * icat kitten: Add a --stdin option to control if image data is read from STDIN (#1308)
  * hints kitten: Start hints numbering at one instead of zero by default. Added an option --hints-offset to control it. (#1289)
  * Fix a regression in the previous release that broke using background for cursor_text_color (#1288)
  * Add a list of user-created kittens to the docs
  * Fix a regression that broke changing mouse wheel scroll direction with negative wheel_scroll_multiplier values in full-screen applications like vim (#1299)
  * Fix background_opacity not working with pure white backgrounds (#1285)
* Tue Jan  8 2019 mvetter@suse.com
- Update to 0.13.2:
  * Add a new option tab_title_template to control how tab titles are formatted. In particular the template can be used to display the tab number next to the title (#1223)
  * Report the current foreground processes as well as the original child process, when using kitty @ ls
  * Use the current working directory of the foreground process for the *_with_cwd actions that open a new window with the current working directory.
  * Add a new copy_or_interrupt action that can be mapped to kbd:ctrl+c. It will copy if there is a selection and interrupt otherwise (#1286)
  * Fix setting background_opacity causing window margins/padding to be slightly different shade from background (#1221)
  * Handle keyboards with a "+" key (#1224)
  * Fix Private use Unicode area characters followed by spaces at the end of text not being rendered correctly (#1210)
  * Fix changing cursor_text_color via remote control not working (#1229)
  * Add an action to resize windows that can be mapped to shortcuts in kitty.conf (#1245)
  * Fix using the new_tab !neighbor action changing the order of the non-neighboring tabs (#1256)
* Sat Dec 15 2018 Michael Vetter <mvetter@suse.com>
- Update to 0.13.1:
  * Fix passing input via the pipe action to a program without a window not working.
  * Linux: Fix a regression in the previous release that caused automatic selection of bold/italic fonts when using aliases such as "monospace" to not work (#1209)
  * Fix resizing window smaller and then restoring causing some wrapped lines to not be properly unwrapped (#1206)
  Changelog from 0.13.0:
  * Add an option scrollback_pager_history_size to tell kitty to store extended scrollback to use when viewing the scrollback buffer in a pager (#970)
  * Modify the kittens sub-system to allow creating custom kittens without any user interface. This is useful for creating more complex actions that can be bound to key presses in kitty.conf. See doc:kittens/custom. (#870)
  * Add a new nth_window action that can be used to go to the nth window and also previously active windows, using negative numbers. Similarly, goto_tab now accepts negative numbers to go to previously active tabs (#1040)
  * Allow hiding the tab bar completely, by setting tab_bar_style to hidden. (#1014)
  * Allow private use unicode characters to stretch over more than a single neighboring space (#1036)
  * Add a new touch_scroll_multiplier option to modify the amount scrolled by high precision scrolling devices such as touchpads (#1129)
  * icat kitten: Implement reading image data from STDIN, if STDIN is not connected to a terminal (#1130)
  * hints kitten: Insert trailing spaces after matches when using the --multiple option. Also add a separate --add-trailing-space option to control this behavior (#1132)
  * Fix the *_with_cwd actions using the cwd of the overlay window rather than the underlying window's cwd (#1045)
  * Fix incorrect key repeat rate on wayland (#1055)
  * Linux: Fix incorrect rendering of some fonts when hinting is disabled at small sizes (#1173)
  * Linux: Fix match rules used as aliases in Fontconfig configuration not being respected (#1085)
  * Linux: Fix a crash when using the GNU Unifont as a fallback font (#1087)
  * Wayland: Fix copying from hidden kitty windows hanging (#1051)
  * Wayland: Add support for the primary selection protocol implemented by some compositors (#1095)
  * Fix expansion of env vars not working in the env directive (#1075)
  * Fix mouse_hide_wait only taking effect after an event such as cursor blink or key press (#1073)
  * Fix the set_background_opacity action not working correctly (#1147)
  * Fix second cell of emoji created using variation selectors not having the same attributes as the first cell (#1109)
  * Fix focusing neighboring windows in the grid layout with less than 4 windows not working (#1115)
  * Fix ctrl+shift+special key not working in normal and application keyboard modes (#1114)
  * Add a terminfo entry for full keyboard mode.
  * Fix incorrect text-antialiasing when using very low background opacity (#1005)
  * When double or triple clicking ignore clicks if they are "far" from each other (#1093)
  * Follow xterm's behavior for the menu key (#597)
  * Fix hover detection of URLs not working when hovering over the first colon and slash characters in short URLs (#1201)
* Tue Nov 27 2018 mvetter@suse.com
- Add: kitty-no-docs.patch: Fix build for Leap 15.0
  There is no python-sphincs >= 1.7 for Leap 15.0.
  After receiving many requests for a package for this version,
  I decided to ship one without docs for it.
* Tue Oct 23 2018 mvetter@suse.com
- Add sphinx version requirements
* Tue Oct  2 2018 mvetter@suse.com
- Update to 0.12.3:
  * Unicode input: Fix an error when searching for the string 'fir' (#1035)
* Mon Sep 24 2018 mvetter@suse.com
- Update to 0.12.2:
  * A new last_used_layout function that can be mapped to a shortcut to switch to the previously used window layout (#870)
  * New neighboring_window and move_window functions to switch to neighboring windows in the current layout, and move them around, similar to window movement in vim (#916)
  * A new pipe function that can be used to pipe the contents of the screen and scrollback buffer to any desired program running in a new window, tab or overlay window. (#933)
  * Add a new kitty --start-as command line flag to start kitty full-screen/maximized/minimized. This replaces the --start-in-fullscreen flag introduced in the previous release (#935)
  * When mapping the new_tab action allow specifying that the tab should open next to the current tab instead of at the end of the tabs list (#979)
  * Fix a bug causing incorrect line ordering when viewing the scrollback buffer if the scrollback buffer is full (#960)
  * Fix drag-scrolling not working when the mouse leaves the window confines (#917)
  * Workaround for broken editors like nano that cannot handle newlines in pasted text (#994)
  * Linux: Ensure that the python embedded in the kitty binary build uses UTF-8 mode to process command-line arguments (#924)
  * Linux: Handle fonts that contain monochrome bitmaps (such as the Terminus TTF font) (#934)
  * Have the kitty --title flag apply to all windows created using kitty --session (#921)
  * Revert change for backspacing of wide characters in the previous release, as it breaks backspacing in some wide character aware programs (#875)
  * Fix kitty @set-colors not working for tab backgrounds when using the fade tabbar style (#937)
  * Linux: Fix window icon not set on X11 for the first OS window (#961)
  * Remote control: Fix the focus_window command not focusing the top-level OS window of the specified kitty window (#1003)
  * Fix using focus_follows_mouse causing text selection with the mouse to malfunction when using multiple kitty windows (#1002)
* Mon Sep 10 2018 mvetter@suse.com
- Update to 0.12.1:
  * Add a new kitty --start-in-fullscreen command line flag to start kitty in full screen mode (#856)
  * Linux: Do not enable IME input via ibus unless the GLFW_IM_MODULE=ibus environment variable is set. IME causes key processing latency and even missed keystrokes for many people, so it is now off by default.
  * Fix backspacing of wide characters in wide-character unaware programs not working (#875)
  * Linux: Fix number pad arrow keys not working when Numlock is off (#857)
  * Wayland: Implement support for clipboard copy/paste (#855)
  * Allow mapping shortcuts using the raw key code from the OS (#848)
  * Allow mapping of individual key-presses without modifiers as shortcuts
  * Fix legacy invocation of icat as kitty icat not working (#850)
  * Improve rendering of wavy underline at small font sizes (#853)
  * Fix a regression in 0.12.0 that broke dynamic resizing of layouts (#860)
  * Wayland: Allow using the kitty --class command line flag to set the app id (#862)
  * Add completion of the kitty command for the fish shell (#829)
  * Linux: Fix XCompose rules with no defined symbol not working (#880)
  * Linux: Fix crash with some Nvidia drivers when creating tabs in the first top level-window after creating a second top-level window. (#873)
* Tue Sep  4 2018 mvetter@suse.com
- Update to 0.12.0:
  * Preserve the mouse selection even when the contents of the screen are scrolled or overwritten provided the new text does not intersect the selected lines.
  * Linux: Implement support for Input Method Extensions (multilingual input using standard keyboards) via IBus (#469)
  * Implement completion for the kitty command in bash and zsh. See Completion for kitty.
  * Render the text under the cursor in a fixed color, configurable via the option cursor_text_color (#126)
  * Add an option env to set environment variables in child processes from kitty.conf
  * Implement high precision scrolling with the trackpad on platforms such as macOS and Wayland that implement it. (#819)
  * Remote control: Allow changing the current window layout with a new kitty @ goto-layout command (#845)
  * Remote control: Allow matching windows by the environment variables of their child process as well
  * Allow running kittens via the remote control system (#738)
  * Allow enabling remote control in only some kitty windows
  * Add a keyboard shortcut to reset the terminal (ctrl+shift+delete). It takes parameters so you can define your own shortcuts to clear the screen/scrollback also (#747)
  * Fix one-pixel line appearing at window edges at some window sizes when displaying images with background opacity enabled (#741)
  * diff kitten: Fix error when right hand side file is binary and left hand side file is text (#752)
  * kitty @ new-window: Add a new option kitty @ new-window --window-type to create top-level OS windows (#770)
  * Fix detection of URLs in HTML source code (URLs inside quotes) (#785)
  * Implement support for emoji skin tone modifiers (#787)
  * Round-trip the zwj unicode character. Rendering of sequences containing zwj is still not implemented, since it can cause the collapse of an unbounded number of characters into a single cell. However, kitty at least preserves the zwj by storing it as a combining character.
  * Linux: Fix slow startup on some systems caused by GLFW searching for joysticks. Since kitty does not use joysticks, disable joystick support. (#830)
* Mon Jul 16 2018 mvetter@suse.com
- Update to 0.11.3:
  * Draw only the minimum borders needed for inactive windows. That is only the borders that separate the inactive window from a neighbor. Note that setting a non-zero window margin overrides this and causes all borders to be drawn. The old behavior of drawing all borders can be restored via the draw_minimal_borders setting in kitty.conf.
  * Fix triple-click to select line not working when the entire line is filled (#703)
  * When dragging to select with the mouse "grab" the mouse so that if it strays into neighboring windows, the selection is still updated (#624)
  * When clicking in the margin/border area of a window, map the click to the nearest cell in the window. Avoids selection with the mouse failing when starting the selection just outside the window.
  * When drag-scrolling stop the scroll when the mouse button is released.
  * Fix a regression in the previous release that caused pasting large amounts of text to be duplicated (#709)
* Mon Jul  2 2018 mvetter@suse.com
- Update to 0.11.2:
  * Linux: Allow using XKB key names to bind shortcuts to keys not supported by GLFW (#665)
  * kitty shell: Ignore failure to read readline history file. Happens if the user migrates their kitty cache directory between systems with incompatible readline implementations.
  * hints kitten: Add a kitty +kitten hints --multiple option to select multiple items (#687)
  * Fix pasting large amounts of text very slow (#682)
  * Add an option single_window_margin_width to allow different margins when only a single window is visible in the layout (#688)
  * Add a kitty --hold command line option to stay open after the child process exits (#667)
  * diff kitten: When triggering a search scroll to the first match automatically
  * kitty --debug-font-fallback also prints out what basic fonts were matched
  * When closing a kitty window reset the mouse cursor to its default shape and ensure it is visible (#655).
  * Remote control: Speed-up reading of command responses
  * Linux installer: Fix installer failing on systems with python < 3.5
  * Support “-T” as an alias for “–title” (#659)
* Mon Jun 18 2018 mvetter@suse.com
- Update to 0.11.1:
  * diff kitten: Implement searching for text in the diff (#574)
  * Add an option startup_session to kitty.conf to specify a default startup session (#641)
  * Add a command line option kitty --wait-for-single-instance-window-close to make kitty --single-instance wait for the closing of the newly opened window before quitting (#630)
  * diff kitten: Allow theming the selection background/foreground as well
  * diff kitten: Display CRLF line endings using the unicode return symbol instead of <d> as it is less intrusive (#638)
  * diff kitten: Fix default foreground/background colors not being restored when kitten quits (#637)
  * Fix kitty @ set-colors --all not working when more than one window present (#632)
  * Fix a regression that broke the legacy increase/decrease_font_size actions
  * Clear scrollback on reset (#631)
* Tue Jun 12 2018 mvetter@suse.com
- Update to 0.11.0:
  * A new tab bar style "fade" in which each tab's edges fade into the background.
  * A new kitten to create dock panels on X11 desktops showing the output from arbitrary terminal programs.
  * Reduce data sent to the GPU per render by 30%% (commit: 8dea5b3e)
  * Implement changing the font size for individual top level (OS) windows (#408)
  * When viewing the scrollback in less using ctrl+shift+h and kitty is currently scrolled, position the scrollback in less to match kitty's scroll position. (#148)
  * ssh kitten: Support all SSH options. It can now be aliased directly to ssh for convenience. (#591)
  * icat kitten: Add kitty +kitten icat --print-window-size to easily detect the window size in pixels from scripting languages (#581)
  * hints kitten: Allow selecting hashes from the terminal with ctrl+shift+p>h useful for git commits. (#604)
  * Allow specifying initial window size in number of cells in addition to pixels (#436)
  * Add a setting to control the margins to the left and right of the tab-bar (#584)
  * When closing a tab switch to the last active tab instead of the right-most tab (#585)
  * Wayland: Fix kitty not starting when using wl_roots based compositors (#157)
  * Wayland: Fix mouse wheel/touchpad scrolling in opposite direction to other apps (#594)
  * Add a config option (editor) to set the EDITOR kitty uses (#580)
  * Add a config option (x11_hide_window_decorations) to hide window decorations under X11/Wayland (#607)
  * Add an option to @set-window-title to make the title change non-permanent (#592)
  * Add support for the CSI t escape code to query window and cell sizes (#581)
  * Linux: Fix fonts not being correctly read from TrueType Collection (.ttc) files (#577)
  * Fix inactive_text_alpha also applying to the tab bar (#612)
  * hints kitten: Fix a regression that caused some blank lines to be not be displayed.
  * Linux: Include a man page and the HTML docs when building the linux-package
  * Remote control: Fix kitty @ sometimes failing to read the response from kitty. (#614)
  * Fix kitty @ set-colors not working with the window border colors. (#623)
- Add BuildRequires: python3-Sphinx for docu building
- Add documentation and man pages to files section
* Thu May 24 2018 mvetter@suse.com
- Update to 0.10.1:
  * Add a kitten to easily ssh into servers that automatically copies the terminfo files over. kitty +kitten ssh myserver.
  * diff kitten: Make the keyboard shortcuts configurable (#563)
  * Allow controlling background_opacity via either keyboard shortcuts or remote control. Note that you must set dynamic_background_opacity yes in kitty.conf first. (#569)
  * diff kitten: Add keybindings to scroll by page
  * diff kitten: Fix incorrect syntax highlighting for a few file formats such as yaml
  * Fix Ctrl+Alt+Space not working in normal and application keyboard modes (#562)
* Tue May 22 2018 mvetter@suse.com
- Update to 0.10.0:
  * A diff kitten to show side-by-side diffs with syntax highlighting and support for images. See diff README.
  * Make windows in the various kitty layouts manually resizable. See the Layouts section of the README for details.
  * Implement support for the SGR faint escape code to make text blend into the background (#446).
  * Make the hints kitten a little smarter, so that URLs that stretch over multiple lines are detected.
    Also improve detection of surrounding brackets/quotes.
  * Make the kitty window id available as the environment variable KITTY_WINDOW_ID (#532).
  * Add a "fat" layout that is similar to the "tall" layout but vertically oriented.
  * Expand environment variables in config file include directives
  * Allow programs running in kitty to read/write from the clipboard. By default only writing is allowed.
  * Fix moving cursor outside a defined page area incorrectly causing the cursor to be placed inside the page area.
    Caused incorrect rendering in neovim, in some situations (#542).
  * Render a couple more powerline symbols directly, bypassing the font (#550).
  * Fix ctrl+alt+<special> not working in normal and application keyboard (#548).
  * Partial fix for rendering Right-to-left languages like Arabic.
  * Fix Ctrl+backspace acting as plain backspace in normal and application keyboard modes (#538).
  * Have the paste_from_selection action paste from the clipboard on platforms
    that do not have a primary selection such as Wayland and macOS (#529)
  * Fix cursor_stop_blinking_after=0 not working (#530)
* Sun May  6 2018 mvetter@suse.com
- Update to 0.9.1:
  * Show a bell symbol on the tab if a bell occurs in one of the windows in the
    tab and the window is not the currently focused window
  * Change the window border color if a bell occurs in an unfocused window. Can
    be disabled by setting the bell_border_color to be the same as the
    inactive_border_color.
  * Unicode input: When searching by name search for prefix matches as well as whole word matches
  * Dynamically allocate the memory used for the scrollback history buffer.
  * Reduces startup memory consumption when using very large scrollback buffer sizes.
  * Add an option to not request window attention on bell.
  * Remote control: Allow matching windows by number (visible position).
  * When triple-clicking select all wrapped lines belonging to a single logical line.
  * hints kitten: Detect bracketed URLs and dont include the closing bracket in the URL.
  * When calling pass_selection_to_program use the current directory of the child process as the cwd of the program.
  * Add a setting to clear all shortcuts defined up to that point in the config file(s)
  * Add a setting (kitty_mod) to change the modifier used by all the default kitty shortcuts, globally
  * Fix Shift+function key not working
  * Support the F13 to F25 function keys
  * Don't fail to start if the user deletes the hintstyle key from their fontconfig configuration.
  * When rendering a private use unicode codepoint and a space as a two cell
    ligature, set the foreground colors of the space cell to match the colors of
    the first cell. Works around applications like powerline that use different
    colors for the two cells.
  * Fix passing @text to other programs such as when viewing the scrollback
    buffer not working correctly if kitty is itself scrolled up.
  * Fix window focus gained/lost events not being reported to child programs
    when switching windows/tabs using the various keyboard shortcuts.
  * Fix tab title not changing to reflect the window title when switching between different windows in a tab
  * Ignore -e if it is specified on the command line. This is for compatibility
    with broken software that assumes terminals should run with an -e option to
    execute commands instead of just passing the commands as arguments.
* Sun Apr 15 2018 avindra@opensuse.org
- Update to 0.9.0
  * A new kitty command shell to allow controlling kitty via
    commands. Press ctrl+shift+escape to run the shell.
  * The hints kitten has become much more powerful. Now in addition
    to URLs you can use it to select word, paths, filenames, lines,
    etc. from the screen. These can be inserted into the terminal,
    copied to clipboard or sent to external programs.
  * Switch to libxkbcommon for keyboard handling. It allows kitty to
    support XCompose and dead keys and also react to keyboard
    remapping/layout change without needing a restart.
  * Add support for multiple-key-sequence shortcuts
  * A new remote control command set-colors to change the current
    and/or configured colors.
  * When double-clicking to select a word, select words that continue
    onto the next/prev line as well.
  * Add an include directive for the config files to read multiple
    config files
  * Improve mouse selection for windows with padding. Moving the
    mouse into the padding area now acts as if the mouse is over
    the nearest cell.
  * Allow setting all 256 terminal colors in the config file
  * Fix using kitty --single-instance to open a new window in a
    running kitty instance, not respecting the --directory flag
  * URL hints: Exclude trailing punctuation from URLs
  * URL hints: Launch the browser from the kitty parent process
    rather than the hints kitten. Fixes launching on some systems
    where xdg-open doesn't like being run from a kitten.
  * Allow using rectangle select mode by pressing shift in addition
    to the rectangle select modifiers even when the terminal program
    has grabbed the mouse.
* Mon Apr  2 2018 glin@suse.com
- Update to 0.8.4
- Drop upstreamed patch: kitty-0.8.2-desktopfile-category.patch
* Tue Mar 20 2018 mvetter@suse.com
- Initial package for openSUSE in version 0.8.2
